@@ -498,7 +498,7 @@ col_do_append_fstr(column_info *cinfo, const int el, const char *separator, cons
       if (len < max_len) {
         va_list ap2;
 
-        G_VA_COPY(ap2, ap);
+        va_copy(ap2, ap);
         vsnprintf(&col_item->col_buf[len], max_len - len, format, ap2);
         va_end(ap2);
       }
@@ -1141,6 +1141,8 @@ set_time_seconds(const frame_data *fd, const nstime_t *ts, gchar *buf)
 {
   int tsprecision;
 
+  ws_assert(fd->has_ts);
+
   switch (timestamp_get_precision()) {
   case TS_PREC_FIXED_SEC:
     tsprecision = WTAP_TSPREC_SEC;
@@ -1204,6 +1206,8 @@ set_time_hour_min_sec(const frame_data *fd, const nstime_t *ts, gchar *buf, char
   gboolean negative = FALSE;
   int tsprecision;
 
+  ws_assert(fd->has_ts);
+
   if (secs < 0) {
     secs = -secs;
     negative = TRUE;
@@ -1416,6 +1420,11 @@ col_set_delta_time(const frame_data *fd, column_info *cinfo, const int col)
 {
   nstime_t del_cap_ts;
 
+  if (!fd->has_ts) {
+    cinfo->columns[col].col_buf[0] = '\0';
+    return;
+  }
+
   frame_delta_abs_time(cinfo->epan, fd, fd->num - 1, &del_cap_ts);
 
   switch (timestamp_get_seconds_type()) {
