@@ -12,7 +12,6 @@
 
 #ifdef DUMP_DFILTER_MACRO
 #include <stdio.h>
-#include <wsutil/ws_printf.h> /* ws_debug_printf */
 #endif
 #include <string.h>
 
@@ -22,6 +21,7 @@
 #include <ftypes/ftypes-int.h>
 #include <epan/uat-int.h>
 #include <epan/proto.h>
+#include <wsutil/glib-compat.h>
 
 typedef struct {
 	const char* name;
@@ -370,8 +370,9 @@ static gboolean macro_update(void* mp, gchar** error) {
 				*w = *r;
 				goto done;
 			case '\\':
-				*(w++) = *(++r);
-				r++;
+				*(w++) = *(r++);
+				if(*r)
+					*(w++) = *(r++);
 				break;
 			case '$': {
 				int cnt = 0;
@@ -485,7 +486,7 @@ static void* macro_copy(void* dest, const void* orig, size_t len _U_) {
 		 */
 
 		do nparts++; while (m->parts[nparts]);
-		d->parts = (gchar **)g_memdup(m->parts,(nparts+1)*(guint)sizeof(void*));
+		d->parts = (gchar **)g_memdup2(m->parts,(nparts+1)*(guint)sizeof(void*));
 		nparts = 0;
 		while(m->parts[nparts]) {
 			if(nparts) {
@@ -500,7 +501,7 @@ static void* macro_copy(void* dest, const void* orig, size_t len _U_) {
 		 * Clone the contents of m->args_pos into d->args_pos.
 		 */
 
-		d->args_pos = (int *)g_memdup(m->args_pos,(--nparts)*(guint)sizeof(int));
+		d->args_pos = (int *)g_memdup2(m->args_pos,(--nparts)*(guint)sizeof(int));
 	}
 
 	DUMP_MACRO(d);
@@ -563,7 +564,7 @@ void dfilter_macro_init(void) {
 				    TRUE,
 				    &macros,
 				    &num_macros,
-				    0, /* doesn't affect anything that requires a GUI update */
+				    UAT_AFFECTS_FIELDS,
 				    "ChDisplayFilterMacrosSection",
 				    macro_copy,
 				    macro_update,
@@ -607,70 +608,70 @@ void dfilter_macro_get_uat(uat_t **dfmu_ptr_ptr) {
 
 void dump_dfilter_macro_t(const dfilter_macro_t *m, const char *function, const char *file, int line)
 {
-	ws_debug_printf("\n<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<\n");
+	printf("\n<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<\n");
 
 	if(m == NULL) {
-		ws_debug_printf("  dfilter_macro_t * == NULL! (via: %s(): %s:%d)\n", function, file, line);
-		ws_debug_printf("\n>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>\n");
+		printf("  dfilter_macro_t * == NULL! (via: %s(): %s:%d)\n", function, file, line);
+		printf("\n>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>\n");
 		return;
 	}
 
-	ws_debug_printf("DUMP of dfilter_macro_t: %p (via: %s(): %s:%d)\n", m, function, file, line);
+	printf("DUMP of dfilter_macro_t: %p (via: %s(): %s:%d)\n", m, function, file, line);
 
-	ws_debug_printf("  &dfilter_macro->name     == %p\n", &m->name);
+	printf("  &dfilter_macro->name     == %p\n", &m->name);
 	if(m->name == NULL) {
-		ws_debug_printf("                ->name     == NULL\n");
+		printf("                ->name     == NULL\n");
 	} else {
-		ws_debug_printf("                ->name     == %p\n", m->name);
-		ws_debug_printf("                ->name     == <%s>\n", m->name);
+		printf("                ->name     == %p\n", m->name);
+		printf("                ->name     == <%s>\n", m->name);
 	}
 
-	ws_debug_printf("  &dfilter_macro->text     == %p\n", &m->text);
+	printf("  &dfilter_macro->text     == %p\n", &m->text);
 	if(m->text == NULL) {
-		ws_debug_printf("                ->text     == NULL\n");
+		printf("                ->text     == NULL\n");
 	} else {
-		ws_debug_printf("                ->text     == %p\n", m->text);
-		ws_debug_printf("                ->text     == <%s>\n", m->text);
+		printf("                ->text     == %p\n", m->text);
+		printf("                ->text     == <%s>\n", m->text);
 	}
 
-	ws_debug_printf("  &dfilter_macro->usable   == %p\n", &m->usable);
-	ws_debug_printf("                ->usable   == %u\n", m->usable);
+	printf("  &dfilter_macro->usable   == %p\n", &m->usable);
+	printf("                ->usable   == %u\n", m->usable);
 
-	ws_debug_printf("  &dfilter_macro->parts    == %p\n", &m->parts);
+	printf("  &dfilter_macro->parts    == %p\n", &m->parts);
 
 	if(m->parts == NULL) {
-		ws_debug_printf("                ->parts    == NULL\n");
+		printf("                ->parts    == NULL\n");
 	} else {
 		int i = 0;
 
 		while (m->parts[i]) {
-			ws_debug_printf("                ->parts[%d] == %p\n", i, m->parts[i]);
-			ws_debug_printf("                ->parts[%d] == <%s>\n", i, m->parts[i]);
+			printf("                ->parts[%d] == %p\n", i, m->parts[i]);
+			printf("                ->parts[%d] == <%s>\n", i, m->parts[i]);
 			i++;
 		}
-		ws_debug_printf("                ->parts[%d] == NULL\n", i);
+		printf("                ->parts[%d] == NULL\n", i);
 	}
 
-	ws_debug_printf("  &dfilter_macro->args_pos == %p\n", &m->args_pos);
+	printf("  &dfilter_macro->args_pos == %p\n", &m->args_pos);
 	if(m->args_pos == NULL) {
-		ws_debug_printf("                ->args_pos == NULL\n");
+		printf("                ->args_pos == NULL\n");
 	} else {
-		ws_debug_printf("                ->args_pos == %p\n", m->args_pos);
-		/*ws_debug_printf("                ->args_pos == <%?>\n", m->args_pos);*/
+		printf("                ->args_pos == %p\n", m->args_pos);
+		/*printf("                ->args_pos == <%?>\n", m->args_pos);*/
 	}
 
-	ws_debug_printf("  &dfilter_macro->argc     == %p\n", &m->argc);
-	ws_debug_printf("                ->argc     == %d\n", m->argc);
+	printf("  &dfilter_macro->argc     == %p\n", &m->argc);
+	printf("                ->argc     == %d\n", m->argc);
 
-	ws_debug_printf("  &dfilter_macro->priv     == %p\n", &m->priv);
+	printf("  &dfilter_macro->priv     == %p\n", &m->priv);
 	if(m->priv == NULL) {
-		ws_debug_printf("                ->priv     == NULL\n");
+		printf("                ->priv     == NULL\n");
 	} else {
-		ws_debug_printf("                ->priv     == %p\n", m->priv);
-		ws_debug_printf("                ->priv     == <%s>\n", (char *)m->priv);
+		printf("                ->priv     == %p\n", m->priv);
+		printf("                ->priv     == <%s>\n", (char *)m->priv);
 	}
 
-	ws_debug_printf("\n>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>\n");
+	printf("\n>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>\n");
 }
 #endif
 
