@@ -456,7 +456,7 @@ dissect_png(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, void *da
         len_field = tvb_get_ntohl(tvb, offset);
 
         type = tvb_get_ntohl(tvb, offset+4);
-        type_str = tvb_get_string_enc(wmem_packet_scope(),
+        type_str = tvb_get_string_enc(pinfo->pool,
                 tvb, offset+4, 4, ENC_ASCII|ENC_NA);
 
         /* 4 byte len field, 4 byte chunk type, 4 byte CRC */
@@ -611,7 +611,7 @@ proto_reg_handoff_png(void)
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 4
