@@ -20,8 +20,10 @@
 */
 
 #include "config.h"
-#include <epan/packet.h>
+
 #include <epan/expert.h>
+#include <epan/packet.h>
+
 #include <file-rbm.h>
 #include <wiretap/ruby_marshal.h>
 
@@ -78,7 +80,7 @@ void proto_reg_handoff_rbm(void);
 
 #define BETWEEN(v, b1, b2) (((v) >= (b1)) && ((v) <= (b2)))
 
-static void dissect_rbm_object(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, gint* offset, gchar** type, gchar** value);
+static void dissect_rbm_object(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, guint* offset, gchar** type, gchar** value);
 
 static void rbm_set_info(packet_info* pinfo, const gchar* str)
 {
@@ -134,7 +136,7 @@ void get_rbm_integer(tvbuff_t* tvb, guint offset, gint32* value, gint* len)
 	}
 }
 
-static void dissect_rbm_integer(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, gint* offset, gchar** value_str)
+static void dissect_rbm_integer(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, guint* offset, gchar** value_str)
 {
 	gint32 value = 0;
 	gint len = 0;
@@ -143,10 +145,10 @@ static void dissect_rbm_integer(tvbuff_t* tvb, packet_info* pinfo, proto_tree* t
 	proto_tree_add_int_format_value(tree, hf_rbm_integer, tvb, *offset, len, value, "%d", value);
 	*offset += len;
 	if (value_str)
-		*value_str = wmem_strdup_printf(wmem_packet_scope(), "%d", value);
+		*value_str = wmem_strdup_printf(pinfo->pool, "%d", value);
 }
 
-static void dissect_rbm_basic(tvbuff_t* tvb _U_, packet_info* pinfo, proto_tree* tree _U_, gint* offset _U_, const guint8 subtype,
+static void dissect_rbm_basic(tvbuff_t* tvb _U_, packet_info* pinfo, proto_tree* tree _U_, guint* offset _U_, const guint8 subtype,
 	gchar** type, gchar** value_str)
 {
 	switch (subtype) {
@@ -167,7 +169,7 @@ static void dissect_rbm_basic(tvbuff_t* tvb _U_, packet_info* pinfo, proto_tree*
 	rbm_set_info(pinfo, *type);
 }
 
-static void dissect_rbm_string_data_trailer(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, gint* offset, const gchar* label,
+static void dissect_rbm_string_data_trailer(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, guint* offset, const gchar* label,
 	const gchar* prefix, const gchar* trailer, gchar** value_str)
 {
 	gint32 value = 0;
@@ -179,19 +181,20 @@ static void dissect_rbm_string_data_trailer(tvbuff_t* tvb, packet_info* pinfo, p
 	get_rbm_integer(tvb, *offset, &value, &len);
 	proto_tree_add_int_format_value(tree, hf_rbm_length, tvb, *offset, len, value, "%d", value);
 	*offset += len;
-	s = (const char*)tvb_get_string_enc(wmem_packet_scope(), tvb, *offset, value, ENC_NA);
+	s = (const char*)tvb_get_string_enc(pinfo->pool, tvb, *offset, value, ENC_NA);
 	proto_tree_add_string_format_value(tree, hf_rbm_string, tvb, *offset, value, s, "%s%s%s", prefix, s, trailer);
 	*offset += value;
-	*value_str = wmem_strdup_printf(wmem_packet_scope(), "%s%s%s", prefix, s, trailer);
+	*value_str = wmem_strdup_printf(pinfo->pool, "%s%s%s", prefix, s, trailer);
 }
 
-static void dissect_rbm_string_data(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, gint* offset, const gchar* label,
+static void dissect_rbm_string_data(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, guint* offset, const gchar* label,
 	const gchar* prefix, gchar** value_str)
 {
 	dissect_rbm_string_data_trailer(tvb, pinfo, tree, offset, label, prefix, "", value_str);
 }
 
-static void dissect_rbm_array(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, gint* offset, gchar** value_str)
+// NOLINTNEXTLINE(misc-no-recursion)
+static void dissect_rbm_array(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, guint* offset, gchar** value_str)
 {
 	gint32 value;
 	gint len;
@@ -214,10 +217,11 @@ static void dissect_rbm_array(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tre
 	proto_item_set_len(array_tree, *offset - offset_start);
 
 	if (value_str)
-		*value_str = wmem_strdup_printf(wmem_packet_scope(), "%d", value);
+		*value_str = wmem_strdup_printf(pinfo->pool, "%d", value);
 }
 
-static void dissect_rbm_hash(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, gint* offset, gchar** value_str)
+// NOLINTNEXTLINE(misc-no-recursion)
+static void dissect_rbm_hash(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, guint* offset, gchar** value_str)
 {
 	gint32 value;
 	gint len;
@@ -248,10 +252,10 @@ static void dissect_rbm_hash(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree
 	proto_item_set_len(hash_tree, *offset - offset_start);
 
 	if (value_str)
-		*value_str = wmem_strdup_printf(wmem_packet_scope(), "%d", value);
+		*value_str = wmem_strdup_printf(pinfo->pool, "%d", value);
 }
 
-static void dissect_rbm_link(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, gint* offset, guint8 subtype,
+static void dissect_rbm_link(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, guint* offset, guint8 subtype,
 	gchar** type, gchar** value_str)
 {
 	gint32 value;
@@ -269,17 +273,17 @@ static void dissect_rbm_link(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree
 			DISSECTOR_ASSERT_NOT_REACHED();
 	}
 
-	rbm_set_info(pinfo, wmem_strdup_printf(wmem_packet_scope(), "%s Link", label));
+	rbm_set_info(pinfo, wmem_strdup_printf(pinfo->pool, "%s Link", label));
 	get_rbm_integer(tvb, *offset, &value, &len);
 	proto_tree_add_int_format_value(tree, hf_rbm_link, tvb, *offset, len, value, "%d", value);
 	*offset += len;
 	if (type)
 		*type = label;
 	if (value_str)
-		*value_str = wmem_strdup_printf(wmem_packet_scope(), "%d", value);
+		*value_str = wmem_strdup_printf(pinfo->pool, "%d", value);
 }
 
-static void dissect_rbm_double(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, gint* offset, gchar** value_str)
+static void dissect_rbm_double(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, guint* offset, gchar** value_str)
 {
 	gint32 value = 0;
 	gdouble valued;
@@ -291,15 +295,15 @@ static void dissect_rbm_double(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tr
 	get_rbm_integer(tvb, *offset, &value, &len);
 	proto_tree_add_int_format_value(tree, hf_rbm_length, tvb, *offset, len, value, "%d", value);
 	*offset += len;
-	s = (const char*)tvb_get_string_enc(wmem_packet_scope(), tvb, *offset, value, ENC_NA);
+	s = (const char*)tvb_get_string_enc(pinfo->pool, tvb, *offset, value, ENC_NA);
 	valued = g_ascii_strtod(s, NULL);
 	proto_tree_add_double(tree, hf_rbm_double, tvb, *offset, value, valued);
 	*offset += value;
 	if (value_str)
-		*value_str = wmem_strdup_printf(wmem_packet_scope(), "%f", valued);
+		*value_str = wmem_strdup_printf(pinfo->pool, "%f", valued);
 }
 
-static void dissect_rbm_struct_data(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, gint* offset, gchar** value_str)
+static void dissect_rbm_struct_data(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, guint* offset, gchar** value_str)
 {
 	gint32 value = 0;
 	gint len = 0;
@@ -313,10 +317,11 @@ static void dissect_rbm_struct_data(tvbuff_t* tvb, packet_info* pinfo, proto_tre
 	proto_tree_add_item(tree, hf_rbm_struct, tvb, *offset + 1, value, ENC_ASCII|ENC_NA);
 	*offset += 1 + value;
 	if (value_str)
-		*value_str = wmem_strdup_printf(wmem_packet_scope(), "%d", value);
+		*value_str = wmem_strdup_printf(pinfo->pool, "%d", value);
 }
 
-static void dissect_rbm_string(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, gint* offset, gchar** value)
+// NOLINTNEXTLINE(misc-no-recursion)
+static void dissect_rbm_string(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, guint* offset, gchar** value)
 {
 	dissect_rbm_string_data(tvb, pinfo, tree, offset, "String", "", value);
 	dissect_rbm_integer(tvb, pinfo, tree, offset, NULL);
@@ -324,7 +329,8 @@ static void dissect_rbm_string(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tr
 	dissect_rbm_object(tvb, pinfo, tree, offset, NULL, NULL);
 }
 
-static void dissect_rbm_regex(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, gint* offset, gchar** value)
+// NOLINTNEXTLINE(misc-no-recursion)
+static void dissect_rbm_regex(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, guint* offset, gchar** value)
 {
 	dissect_rbm_string_data_trailer(tvb, pinfo, tree, offset, "Regexp", "/", "/", value);
 	proto_tree_add_item(tree, hf_rbm_regex_param, tvb, *offset, 1, ENC_NA);
@@ -334,23 +340,25 @@ static void dissect_rbm_regex(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tre
 	dissect_rbm_object(tvb, pinfo, tree, offset, NULL, NULL);
 }
 
-static void dissect_rbm_class(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, gint* offset, gchar** value_str)
+static void dissect_rbm_class(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, guint* offset, gchar** value_str)
 {
 	dissect_rbm_string_data(tvb, pinfo, tree, offset, "Class", "", value_str);
 }
 
-static void dissect_rbm_userclass(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, gint* offset, gchar** value)
+// NOLINTNEXTLINE(misc-no-recursion)
+static void dissect_rbm_userclass(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, guint* offset, gchar** value)
 {
 	rbm_set_info(pinfo, "UserClass");
 	dissect_rbm_object(tvb, pinfo, tree, offset, NULL, value);
 }
 
-static void dissect_rbm_symbol(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, gint* offset, gchar** value_str)
+static void dissect_rbm_symbol(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, guint* offset, gchar** value_str)
 {
 	dissect_rbm_string_data(tvb, pinfo, tree, offset, "Symbol", ":", value_str);
 }
 
-static void dissect_rbm_variable(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, gint* offset, gchar** value_str)
+// NOLINTNEXTLINE(misc-no-recursion)
+static void dissect_rbm_variable(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, guint* offset, gchar** value_str)
 {
 	gint offset_start = *offset;
 	proto_tree* variable_tree = proto_tree_add_subtree(tree, tvb, *offset, 0, ett_variable, NULL, "Variable");
@@ -358,18 +366,20 @@ static void dissect_rbm_variable(tvbuff_t* tvb, packet_info* pinfo, proto_tree*
 	proto_item_set_len(variable_tree, *offset - offset_start);
 }
 
-static void dissect_rbm_module(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, gint* offset, gchar** value_str)
+static void dissect_rbm_module(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, guint* offset, gchar** value_str)
 {
 	dissect_rbm_string_data(tvb, pinfo, tree, offset, "Module", "", value_str);
 }
 
-static void dissect_rbm_struct(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, gint* offset, gchar** value)
+// NOLINTNEXTLINE(misc-no-recursion)
+static void dissect_rbm_struct(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, guint* offset, gchar** value)
 {
 	dissect_rbm_struct_data(tvb, pinfo, tree, offset, value);
 	dissect_rbm_hash(tvb, pinfo, tree, offset, NULL);
 }
 
-static void dissect_rbm_drb(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, gint* offset)
+// NOLINTNEXTLINE(misc-no-recursion)
+static void dissect_rbm_drb(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, guint* offset)
 {
 	gint offset_start = *offset;
 	proto_tree* drb_tree = proto_tree_add_subtree(tree, tvb, *offset, 0, ett_variable, NULL, "Objects");
@@ -378,7 +388,8 @@ static void dissect_rbm_drb(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree,
 	proto_item_set_len(drb_tree, *offset - offset_start);
 }
 
-static void dissect_rbm_rubyobject(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, gint* offset)
+// NOLINTNEXTLINE(misc-no-recursion)
+static void dissect_rbm_rubyobject(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, guint* offset)
 {
 	gint offset_start = *offset;
 	proto_tree* obj_tree = proto_tree_add_subtree(tree, tvb, *offset, 0, ett_variable, NULL, "Ruby Object");
@@ -395,7 +406,8 @@ static void dissect_rbm_rubyobject(tvbuff_t* tvb, packet_info* pinfo, proto_tree
 	proto_item_set_len(obj_tree, *offset - offset_start);
 }
 
-static void dissect_rbm_extended(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, gint* offset)
+// NOLINTNEXTLINE(misc-no-recursion)
+static void dissect_rbm_extended(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, guint* offset)
 {
 	gint offset_start = *offset;
 	proto_tree* ext_tree = proto_tree_add_subtree(tree, tvb, *offset, 0, ett_variable, NULL, "Extended");
@@ -405,7 +417,8 @@ static void dissect_rbm_extended(tvbuff_t* tvb, packet_info* pinfo, proto_tree*
 	proto_item_set_len(ext_tree, *offset - offset_start);
 }
 
-static void dissect_rbm_object(tvbuff_t* tvb, packet_info* pinfo, proto_tree* ptree, gint* offset, gchar** type, gchar** value)
+// NOLINTNEXTLINE(misc-no-recursion)
+static void dissect_rbm_object(tvbuff_t* tvb, packet_info* pinfo, proto_tree* ptree, guint* offset, gchar** type, gchar** value)
 {
 	guint8 subtype = tvb_get_guint8(tvb, *offset);
 	proto_tree* tree;
@@ -418,6 +431,8 @@ static void dissect_rbm_object(tvbuff_t* tvb, packet_info* pinfo, proto_tree* pt
 	proto_tree_add_item(tree, hf_rbm_type, tvb, *offset, 1, ENC_NA);
 	*offset += 1;
 
+	increment_dissection_depth(pinfo);
+
 	switch (subtype) {
 		case '0':
 		case 'T':
@@ -507,9 +522,11 @@ static void dissect_rbm_object(tvbuff_t* tvb, packet_info* pinfo, proto_tree* pt
 		*type = type_local;
 	if (value)
 		*value = value_local;
+
+	decrement_dissection_depth(pinfo);
 }
 
-static gboolean dissect_rbm_header(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, gint* offset)
+static gboolean dissect_rbm_header(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, guint* offset)
 {
 	guint8 major;
 	guint8 minor;
@@ -518,7 +535,7 @@ static gboolean dissect_rbm_header(tvbuff_t* tvb, packet_info* pinfo, proto_tree
 	major = tvb_get_guint8(tvb, *offset);
 	minor = tvb_get_guint8(tvb, *offset + 1);
 
-	version = wmem_strdup_printf(wmem_packet_scope(), "%u.%u", major, minor);
+	version = wmem_strdup_printf(pinfo->pool, "%u.%u", major, minor);
 	proto_tree_add_string_format(tree, hf_rbm_version, tvb, *offset, 2, version, "Version: %s", version);
 	*offset += 2;
 
@@ -530,7 +547,8 @@ static gboolean dissect_rbm_header(tvbuff_t* tvb, packet_info* pinfo, proto_tree
 	return TRUE;
 }
 
-void dissect_rbm_inline(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, gint* offset, gchar** type, gchar** value)
+// NOLINTNEXTLINE(misc-no-recursion)
+void dissect_rbm_inline(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, guint* offset, gchar** type, gchar** value)
 {
 	if (!dissect_rbm_header(tvb, pinfo, tree, offset))
 		return;
@@ -539,7 +557,7 @@ void dissect_rbm_inline(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, gin
 
 static int dissect_rbm(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, void* data _U_)
 {
-	gint offset = 0;
+	guint offset = 0;
 	proto_item* ti;
 	proto_tree* rbm_tree;
 
