@@ -262,9 +262,40 @@ static const value_string vals_ctype[] = {
 	{ 42, "application/octet-stream" },
 	{ 47, "application/exi" },
 	{ 50, "application/json" },
+	{ 51, "application/json-patch+json" },
+	{ 52, "application/merge-patch+json" },
 	{ 60, "application/cbor" },
+	{ 61, "application/cwt" },
+	{ 62, "application/multipart-core" },
+	{ 96, "application/cose; cose-type=\"cose-encrypt\"" },
+	{ 97, "application/cose; cose-type=\"cose-mac\"" },
+	{ 98, "application/cose; cose-type=\"cose-sign\"" },
+	{ 101, "application/cose-key" },
+	{ 102, "application/cose-key-set" },
+	{ 110, "application/senml+json" },
+	{ 111, "application/sensml+json" },
+	{ 112, "application/senml+cbor" },
+	{ 113, "application/sensml+cbor" },
+	{ 114, "application/senml-exi" },
+	{ 115, "application/sensml-exi" },
+	{ 256, "application/coap-group+json" },
+	{ 271, "application/dots+cbor" },
+	{ 272, "application/missing-blocks+cbor-seq" },
+	{ 280, "application/pkcs7-mime; smime-type=server-generated-key" },
+	{ 281, "application/pkcs7-mime; smime-type=certs-only" },
+	{ 284, "application/pkcs8" },
+	{ 285, "application/csrattrs" },
+	{ 286, "application/pkcs10" },
+	{ 287, "application/pkix-cert" },
+	{ 310, "application/senml+xml" },
+	{ 311, "application/sensml+xml" },
+	{ 320, "application/senml-etch+json" },
+	{ 322, "application/senml-etch+cbor" },
+	{ 432, "application/td+json" },
 	{ 1542, "application/vnd.oma.lwm2m+tlv" },
 	{ 1543, "application/vnd.oma.lwm2m+json" },
+	{ 10000, "application/vnd.ocf+cbor" },
+	{ 10001, "application/oscore" },
 	{ 11542, "application/vnd.oma.lwm2m+tlv" },
 	{ 11543, "application/vnd.oma.lwm2m+json" },
 	{ 0, NULL },
@@ -1033,7 +1064,7 @@ dissect_coap_payload(tvbuff_t *tvb, packet_info *pinfo, proto_tree *coap_tree, p
 	tvbuff_t   *payload_tvb;
 	guint	    payload_length = offset_end - offset;
 	const char *coap_ctype_str_dis;
-	http_message_info_t message_info;
+	http_message_info_t message_info = {0};
 	char	    str_payload[80];
 
 	/* coinfo->ctype_value == DEFAULT_COAP_CTYPE_VALUE: No Content-Format option present */
