@@ -160,7 +160,7 @@ static gboolean communityid_tuple_lt(guint8 addr_len,
                                      const guint16 *sport, const guint16 *dport)
 {
     int addrcmp = memcmp(saddr, daddr, addr_len);
-    int ports_lt = (sport != NULL && dport != NULL) ? *sport < *dport : TRUE;
+    int ports_lt = (sport != NULL && dport != NULL) ? GUINT16_FROM_BE(*sport) < GUINT16_FROM_BE(*dport) : TRUE;
     return addrcmp < 0 || (addrcmp == 0 && ports_lt);
 }
 
