@@ -7,19 +7,7 @@
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 /* Fields description are taken from
@@ -485,6 +473,7 @@ dissect_corosync_totemsrp_srp_addr(tvbuff_t *tvb,
 }
 
 static int
+// NOLINTNEXTLINE(misc-no-recursion)
 dissect_corosync_totemsrp_mcast(tvbuff_t *tvb,
                                   packet_info *pinfo, proto_tree *tree,
                                   guint length, int offset,
@@ -809,6 +798,7 @@ dissect_corosync_totemsrp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_
 #define COROSYNC_TOTEMSRP_TEST_BIG_ENDIAN       0xFF22
 
 static int
+// NOLINTNEXTLINE(misc-no-recursion)
 dissect_corosync_totemsrp0(tvbuff_t *tvb,
                            packet_info *pinfo, proto_tree *tree,
                            gboolean encapsulated)
@@ -880,6 +870,7 @@ dissect_corosync_totemsrp0(tvbuff_t *tvb,
   info.nodeid = corosync_totemsrp_get_guint32(tvb, offset, encoding);
   offset += 4;
 
+  increment_dissection_depth(pinfo);
   switch (message_header__type) {
   case COROSYNC_TOTEMSRP_MESSAGE_TYPE_ORF_TOKEN:
     dissect_corosync_totemsrp_orf_token(tvb, pinfo, corosync_tree, length, offset, encoding);
@@ -908,6 +899,7 @@ dissect_corosync_totemsrp0(tvbuff_t *tvb,
   default:
     break;
   }
+  decrement_dissection_depth(pinfo);
 
   return length;
 }
@@ -1173,7 +1165,7 @@ proto_reg_handoff_corosync_totemsrp(void)
 
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 2
