@@ -19,13 +19,14 @@
 #include <wsutil/wsgcrypt.h>
 #include <wsutil/str_util.h>
 
+#include <packet-tls.h>
+#include <packet-dtls.h>
+
 void proto_register_data(void);
 void proto_reg_handoff_data(void);
 
-/* proto_data cannot be static because it's referenced in the
- * print routines
- */
-int proto_data = -1;
+
+static int proto_data = -1;
 
 #define DATA_HFI_INIT HFI_INIT(proto_data)
 
@@ -112,7 +113,7 @@ dissect_data(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_
 				cp = tvb_get_ptr(tvb, 0, bytes);
 
 				gcry_md_hash_buffer(GCRY_MD_MD5, digest, cp, bytes);
-				digest_string = bytestring_to_str(wmem_packet_scope(), digest, HASH_MD5_LENGTH, '\0');
+				digest_string = bytes_to_str_punct(pinfo->pool, digest, HASH_MD5_LENGTH, '\0');
 				ti = proto_tree_add_string(data_tree, &hfi_data_md5_hash, tvb, 0, 0, digest_string);
 				proto_item_set_generated(ti);
 			}
@@ -190,10 +191,12 @@ void
 proto_reg_handoff_data(void)
 {
 	dissector_add_string("media_type", "application/octet-stream", data_handle);
+	ssl_dissector_add(0, data_handle);
+	dtls_dissector_add(0, data_handle);
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 8
