@@ -383,10 +383,6 @@ static const value_string yes_no_val[] = {
     { 0  , NULL },
 };
 
-static const true_false_string tfs_dplay_flag = {
-    "present",
-    "absent"
-};
 
 /* borrowed from epan/dissectors/packets-smb-common.c */
 static gint display_unicode_string(proto_tree *tree, gint hf_index, tvbuff_t *tvb, gint offset)
@@ -1191,58 +1187,58 @@ void proto_register_dplay(void)
         NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_flags_no_create_players,
         { "no create players flag", "dplay.flags.no_create_players", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_FLAG_NO_CREATE_PLAYERS, "No Create Players", HFILL}},
+        TFS(&tfs_present_absent), DPLAY_FLAG_NO_CREATE_PLAYERS, "No Create Players", HFILL}},
     { &hf_dplay_flags_0002,
         { "unused", "dplay.flags.unused", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_FLAG_0002, NULL, HFILL}},
+        TFS(&tfs_present_absent), DPLAY_FLAG_0002, NULL, HFILL}},
     { &hf_dplay_flags_migrate_host,
         { "migrate host flag", "dplay.flags.migrate_host", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_FLAG_MIGRATE_HOST, "Migrate Host", HFILL}},
+        TFS(&tfs_present_absent), DPLAY_FLAG_MIGRATE_HOST, "Migrate Host", HFILL}},
     { &hf_dplay_flags_short_player_msg,
         { "short player message", "dplay.flags.short_player_msg", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_FLAG_SHORT_PLAYER_MSG, "Short Player Msg", HFILL}},
+        TFS(&tfs_present_absent), DPLAY_FLAG_SHORT_PLAYER_MSG, "Short Player Msg", HFILL}},
     { &hf_dplay_flags_ignored,
         { "ignored", "dplay.ignored", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_FLAG_IGNORED, NULL, HFILL}},
+        TFS(&tfs_present_absent), DPLAY_FLAG_IGNORED, NULL, HFILL}},
     { &hf_dplay_flags_can_join,
         { "can join", "dplay.flags.can_join", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_FLAG_CAN_JOIN, NULL, HFILL}},
+        TFS(&tfs_present_absent), DPLAY_FLAG_CAN_JOIN, NULL, HFILL}},
     { &hf_dplay_flags_use_ping,
         { "use ping", "dplay.flags.use_ping", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_FLAG_USE_PING, NULL, HFILL}},
+        TFS(&tfs_present_absent), DPLAY_FLAG_USE_PING, NULL, HFILL}},
     { &hf_dplay_flags_no_player_updates,
         { "no player updates", "dplay.flags.no_player_updates", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_FLAG_NO_P_UPD, NULL, HFILL}},
+        TFS(&tfs_present_absent), DPLAY_FLAG_NO_P_UPD, NULL, HFILL}},
     { &hf_dplay_flags_use_auth,
         { "use authentication", "dplay.flags.use_auth", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_FLAG_USE_AUTH, "Use Auth", HFILL}},
+        TFS(&tfs_present_absent), DPLAY_FLAG_USE_AUTH, "Use Auth", HFILL}},
     { &hf_dplay_flags_private_session,
         { "private session", "dplay.flags.priv_sess", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_FLAG_PRIV_SESS, "Priv Session", HFILL}},
+        TFS(&tfs_present_absent), DPLAY_FLAG_PRIV_SESS, "Priv Session", HFILL}},
     { &hf_dplay_flags_password_req,
         { "password required", "dplay.flags.pass_req", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_FLAG_PASS_REQ, "Pass Req", HFILL}},
+        TFS(&tfs_present_absent), DPLAY_FLAG_PASS_REQ, "Pass Req", HFILL}},
     { &hf_dplay_flags_route,
         { "route via game host", "dplay.flags.route", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_FLAG_ROUTE, "Route", HFILL}},
+        TFS(&tfs_present_absent), DPLAY_FLAG_ROUTE, "Route", HFILL}},
     { &hf_dplay_flags_server_player_only,
         { "get server player only", "dplay.flags.srv_p_only", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_FLAG_SRV_ONLY, "Svr Player Only", HFILL}},
+        TFS(&tfs_present_absent), DPLAY_FLAG_SRV_ONLY, "Svr Player Only", HFILL}},
     { &hf_dplay_flags_reliable,
         { "use reliable protocol", "dplay.flags.reliable", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_FLAG_RELIABLE, "Reliable", HFILL}},
+        TFS(&tfs_present_absent), DPLAY_FLAG_RELIABLE, "Reliable", HFILL}},
     { &hf_dplay_flags_preserve_order,
         { "preserve order", "dplay.flags.order", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_FLAG_ORDER, "Order", HFILL}},
+        TFS(&tfs_present_absent), DPLAY_FLAG_ORDER, "Order", HFILL}},
     { &hf_dplay_flags_optimize_latency,
         { "optimize for latency", "dplay.flags.opt_latency", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_FLAG_OPT_LAT, "Opt Latency", HFILL}},
+        TFS(&tfs_present_absent), DPLAY_FLAG_OPT_LAT, "Opt Latency", HFILL}},
     { &hf_dplay_flags_acqire_voice,
         { "acquire voice", "dplay.flags.acq_voice", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_FLAG_ACQ_VOICE, "Acq Voice", HFILL}},
+        TFS(&tfs_present_absent), DPLAY_FLAG_ACQ_VOICE, "Acq Voice", HFILL}},
     { &hf_dplay_flags_no_sess_desc_changes,
         { "no session desc changes", "dplay.flags.no_sess_desc", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_FLAG_NO_SESS_DESC_CHANGES, "No Sess Desc Changes", HFILL}},
+        TFS(&tfs_present_absent), DPLAY_FLAG_NO_SESS_DESC_CHANGES, "No Sess Desc Changes", HFILL}},
     { &hf_dplay_instance_guid,
         { "DirectPlay instance guid", "dplay.instance.guid", FT_GUID, BASE_NONE,
         NULL, 0x0, NULL, HFILL}},
@@ -1292,16 +1288,16 @@ void proto_register_dplay(void)
         NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_pp_flag_sysplayer,
         { "is system player", "dplay.pp.flags.sysplayer", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_PP_FLAG_SYSPLAYER, NULL, HFILL}},
+        TFS(&tfs_present_absent), DPLAY_PP_FLAG_SYSPLAYER, NULL, HFILL}},
     { &hf_dplay_pp_flag_nameserver,
         { "is name server", "dplay.pp.flags.nameserver", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_PP_FLAG_NAMESERVER, NULL, HFILL}},
+        TFS(&tfs_present_absent), DPLAY_PP_FLAG_NAMESERVER, NULL, HFILL}},
     { &hf_dplay_pp_flag_in_group,
         { "in group", "dplay.pp.flags.in_group", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_PP_FLAG_IN_GROUP, NULL, HFILL}},
+        TFS(&tfs_present_absent), DPLAY_PP_FLAG_IN_GROUP, NULL, HFILL}},
     { &hf_dplay_pp_flag_sending,
         { "sending player on local machine", "dplay.pp.flags.sending", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_SPP_FLAG_SENDING, NULL, HFILL}},
+        TFS(&tfs_present_absent), DPLAY_SPP_FLAG_SENDING, NULL, HFILL}},
     { &hf_dplay_pp_id,
         { "PackedPlayer ID", "dplay.pp.id", FT_BYTES, BASE_NONE,
         NULL, 0x0, NULL, HFILL}},
@@ -1360,16 +1356,16 @@ void proto_register_dplay(void)
         NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_spp_flags_sysplayer,
         { "is system player", "dplay.spp.flags.sysplayer", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_SPP_FLAG_SYSPLAYER, NULL, HFILL}},
+        TFS(&tfs_present_absent), DPLAY_SPP_FLAG_SYSPLAYER, NULL, HFILL}},
     { &hf_dplay_spp_flags_nameserver,
         { "is name server", "dplay.spp.flags.nameserver", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_SPP_FLAG_NAMESERVER, NULL, HFILL}},
+        TFS(&tfs_present_absent), DPLAY_SPP_FLAG_NAMESERVER, NULL, HFILL}},
     { &hf_dplay_spp_flags_in_group,
         { "in group", "dplay.spp.flags.in_group", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_SPP_FLAG_IN_GROUP, NULL, HFILL}},
+        TFS(&tfs_present_absent), DPLAY_SPP_FLAG_IN_GROUP, NULL, HFILL}},
     { &hf_dplay_spp_flags_sending,
         { "sending player on local machine", "dplay.spp.flags.sending", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_SPP_FLAG_SENDING, NULL, HFILL}},
+        TFS(&tfs_present_absent), DPLAY_SPP_FLAG_SENDING, NULL, HFILL}},
     { &hf_dplay_spp_id,
         { "SuperPackedPlayer ID", "dplay.spp.id", FT_BYTES, BASE_NONE,
         NULL, 0x0, NULL, HFILL}},
@@ -1480,13 +1476,13 @@ void proto_register_dplay(void)
         NULL, 0x0, NULL, HFILL}},
     { &hf_enum_sess_flag_join,
         { "Enumerate joinable sessions", "dplay.type02.joinable", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_ENUM_SESS_FLAG_JOIN, "Joinable", HFILL}},
+        TFS(&tfs_present_absent), DPLAY_ENUM_SESS_FLAG_JOIN, "Joinable", HFILL}},
     { &hf_enum_sess_flag_all,
         { "Enumerate all sessions", "dplay.type02.all", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_ENUM_SESS_FLAG_ALL, "All", HFILL}},
+        TFS(&tfs_present_absent), DPLAY_ENUM_SESS_FLAG_ALL, "All", HFILL}},
     { &hf_enum_sess_flag_passwd,
         { "Enumerate sessions requiring a password", "dplay.type02.pw_req", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_ENUM_SESS_FLAG_PASSWD, "Password", HFILL}},
+        TFS(&tfs_present_absent), DPLAY_ENUM_SESS_FLAG_PASSWD, "Password", HFILL}},
 
     /* Data fields for message type 0x0005 */
     { &hf_dplay_type_05_flags,
@@ -1494,19 +1490,19 @@ void proto_register_dplay(void)
         NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_type_05_system_player,
         { "is system player", "dplay.type_05.flags.sys_player", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_TYPE05_FLAG_SYSPLAYER, NULL, HFILL}},
+        TFS(&tfs_present_absent), DPLAY_TYPE05_FLAG_SYSPLAYER, NULL, HFILL}},
     { &hf_dplay_type_05_name_server,
         { "is name server", "dplay.type_05.flags.name_server", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_TYPE05_FLAG_NAMESERVER, NULL, HFILL}},
+        TFS(&tfs_present_absent), DPLAY_TYPE05_FLAG_NAMESERVER, NULL, HFILL}},
     { &hf_dplay_type_05_local,
         { "is local player", "dplay.type_05.flags.local", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_TYPE05_FLAG_LOCAL, NULL, HFILL}},
+        TFS(&tfs_present_absent), DPLAY_TYPE05_FLAG_LOCAL, NULL, HFILL}},
     { &hf_dplay_type_05_unknown,
         { "unknown", "dplay.type_05.flags.unknown", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_TYPE05_FLAG_UNKNOWN, NULL, HFILL}},
+        TFS(&tfs_present_absent), DPLAY_TYPE05_FLAG_UNKNOWN, NULL, HFILL}},
     { &hf_dplay_type_05_secure,
         { "is secure session", "dplay.type_05.flags.secure", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_TYPE05_FLAG_SECURE, NULL, HFILL}},
+        TFS(&tfs_present_absent), DPLAY_TYPE05_FLAG_SECURE, NULL, HFILL}},
 
     /* Data fields for message type 0x0007 */
     { &hf_dplay_type_07_dpid,
