@@ -355,6 +355,7 @@ static gint dissect_etf_dist_header(packet_info *pinfo _U_, tvbuff_t *tvb, gint
   return offset;
 }
 
+// NOLINTNEXTLINE(misc-no-recursion)
 static gint dissect_etf_tuple_content(gboolean large, packet_info *pinfo, tvbuff_t *tvb, gint offset, proto_tree *tree, const gchar **value_str _U_) {
   guint32 arity, i;
 
@@ -398,13 +399,13 @@ static gint dissect_etf_big_ext(tvbuff_t *tvb, gint offset, guint32 len, proto_t
           *value_str = wmem_strdup_printf(wmem_packet_scope(), "%s%" G_GINT64_MODIFIER "u",
                                           sign ? "-"  : "", big_val);
       } if (len < 64) {
-        gchar *buf, *buf_ptr;
+        wmem_strbuf_t *strbuf = wmem_strbuf_sized_new(wmem_packet_scope(), len*1+3+1, len*1+3+1);
 
-        buf=buf_ptr=(gchar *)wmem_alloc(wmem_packet_scope(), len*1+3+1);
-        buf_ptr = g_stpcpy(buf, "0x");
-        for (i = len - 1; i >= 0; i--)
-          buf_ptr = guint8_to_hex(buf_ptr, tvb_get_guint8(tvb, offset + i));
-        *buf_ptr = 0;
+        wmem_strbuf_append(strbuf, "0x");
+        for (i = len - 1; i >= 0; i--) {
+          wmem_strbuf_append_printf(strbuf, "%02x", tvb_get_guint8(tvb, offset + i));
+        }
+        char *buf = wmem_strbuf_finalize(strbuf);
 
         proto_tree_add_string_format_value(tree, hf_erldp_big_ext_str, tvb, offset, len, buf, "%s", buf);
 
@@ -416,12 +417,15 @@ static gint dissect_etf_big_ext(tvbuff_t *tvb, gint offset, guint32 len, proto_t
       return offset + len;
 }
 
+// NOLINTNEXTLINE(misc-no-recursion)
 static gint dissect_etf_type_content(guint8 tag, packet_info *pinfo, tvbuff_t *tvb, gint offset, proto_tree *tree, const gchar **value_str) {
   gint32 int_val;
   guint32 len, i, uint_val;
   guint32 id;
   const guint8 *str_val;
 
+  increment_dissection_depth(pinfo);
+
   switch (tag) {
     case ATOM_CACHE_REF:
       proto_tree_add_item_ret_uint(tree, hf_erldp_atom_cache_ref, tvb, offset, 1, ENC_BIG_ENDIAN, &uint_val);
@@ -624,6 +628,8 @@ static gint dissect_etf_type_content(guint8 tag, packet_info *pinfo, tvbuff_t *t
       break;
   }
 
+  decrement_dissection_depth(pinfo);
+
   return offset;
 }
 
@@ -738,6 +744,7 @@ static gint dissect_etf_versioned_type(const gchar *label, packet_info *pinfo, t
   return dissect_etf_type(label, pinfo, tvb, offset, tree);
 }
 
+// NOLINTNEXTLINE(misc-no-recursion)
 static gint dissect_etf_type(const gchar *label, packet_info *pinfo, tvbuff_t *tvb, gint offset, proto_tree *tree) {
   gint begin = offset;
   guint32 tag;
@@ -919,13 +926,13 @@ static int dissect_erldp_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree
 
       offset = dissect_etf_versioned_type("ControlMessage", pinfo, tvb, offset, erldp_tree);
       if (tvb_reported_length_remaining(tvb, offset) > 0) {
-        offset = dissect_etf_versioned_type("Message", pinfo, tvb, offset, erldp_tree);
+        dissect_etf_versioned_type("Message", pinfo, tvb, offset, erldp_tree);
       }
       break;
 
     case VERSION_MAGIC:
       next_tvb = tvb_new_subset_length_caplen(tvb, offset, -1, 4 + msg_len - offset);
-      offset += dissect_etf_pdu(next_tvb, pinfo, erldp_tree, "DistributionHeader");
+      dissect_etf_pdu(next_tvb, pinfo, erldp_tree, "DistributionHeader");
      break;
 
     default:
