@@ -6,19 +6,7 @@
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "config.h"
@@ -126,9 +114,13 @@ dissect_fcfzs_zoneset(tvbuff_t *tvb, packet_info* pinfo, proto_tree *tree, int o
         len = tvb_get_guint8(tvb, offset);
         proto_tree_add_item(tree, hf_fcfzs_zonesetnmlen, tvb, offset,
                             1, ENC_BIG_ENDIAN);
-        proto_tree_add_item(tree, hf_fcfzs_zonesetname, tvb, offset+4,
+        offset += 4;
+        proto_tree_add_item(tree, hf_fcfzs_zonesetname, tvb, offset,
                             len, ENC_ASCII|ENC_NA);
-        offset += 4 + len + (4-(len % 4));
+        offset += len;
+        /* Fill Bytes */
+        if (len % 4)
+            offset += 4 - (len % 4);
 
 
         /* Number of zones */
@@ -141,9 +133,13 @@ dissect_fcfzs_zoneset(tvbuff_t *tvb, packet_info* pinfo, proto_tree *tree, int o
             len = tvb_get_guint8(tvb, offset);
             proto_tree_add_item(tree, hf_fcfzs_zonenmlen, tvb, offset,
                                 1, ENC_BIG_ENDIAN);
-            proto_tree_add_item(tree, hf_fcfzs_zonename, tvb, offset+4,
+            offset += 4;
+            proto_tree_add_item(tree, hf_fcfzs_zonename, tvb, offset,
                                 len, ENC_ASCII|ENC_NA);
-            offset += 4 + len + (4-(len % 4));
+            offset += len;
+            /* Fill Bytes */
+            if (len % 4)
+                offset += 4 - (len % 4);
 
             nummbrs = tvb_get_ntohl(tvb, offset);
             proto_tree_add_item(tree, hf_fcfzs_nummbrentries, tvb, offset,
@@ -197,7 +193,7 @@ dissect_fcfzs_zoneset(tvbuff_t *tvb, packet_info* pinfo, proto_tree *tree, int o
 static void
 dissect_fcfzs_gzc(tvbuff_t *tvb, int offset, proto_tree *parent_tree, gboolean isreq)
 {
-    static const int * flags[] = {
+    static int * const flags[] = {
         &hf_fcfzs_gzc_flags_hard_zones,
         &hf_fcfzs_gzc_flags_soft_zones,
         &hf_fcfzs_gzc_flags_zoneset_db,
@@ -216,7 +212,7 @@ static void
 dissect_fcfzs_gest(tvbuff_t *tvb, proto_tree *parent_tree, gboolean isreq)
 {
     int offset = 16;            /* past the fc_ct header */
-    static const int * flags[] = {
+    static int * const flags[] = {
         &hf_fcfzs_soft_zone_set_enforced,
         &hf_fcfzs_hard_zone_set_enforced,
         NULL
@@ -866,7 +862,7 @@ proto_reg_handoff_fcfzs(void)
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 4
