@@ -1205,6 +1205,7 @@ dissect_swils_zone_mbr(tvbuff_t *tvb, packet_info* pinfo, proto_tree *zmbr_tree,
 }
 
 static void
+// NOLINTNEXTLINE(misc-no-recursion)
 dissect_swils_zone_obj(tvbuff_t *tvb, packet_info* pinfo, proto_tree *zobj_tree, int offset)
 {
     proto_tree *zmbr_tree;
@@ -1227,6 +1228,7 @@ dissect_swils_zone_obj(tvbuff_t *tvb, packet_info* pinfo, proto_tree *zobj_tree,
     offset += 8 + ZONENAME_LEN(tvb, offset+4);
     for (i = 0; i < numrec; i++) {
         if (objtype == FC_SWILS_ZONEOBJ_ZONESET) {
+            // We recurse here, but we'll run out of packet before we run out of stack.
             dissect_swils_zone_obj(tvb, pinfo, zobj_tree, offset);
             offset += get_zoneobj_len(tvb, offset);
         }
@@ -1969,7 +1971,7 @@ proto_register_fcswils(void)
 
 #if 0
         { &hf_swils_fspfh_cmd,
-          {"Command:", "swils.fspf.cmd",
+          {"Command", "swils.fspf.cmd",
            FT_UINT8, BASE_HEX, NULL, 0x0,
            NULL, HFILL}},
 #endif
@@ -2200,7 +2202,7 @@ proto_register_fcswils(void)
            NULL, HFILL}},
 
         { &hf_swils_rjtdet,
-          {"Reason Code Explanantion", "swils.rjt.reasonexpl",
+          {"Reason Code Explanation", "swils.rjt.reasonexpl",
            FT_UINT8, BASE_HEX, VALS(fc_swils_deterr_val), 0x0,
            NULL, HFILL}},
 
