@@ -110,6 +110,7 @@ static gint ett_bblog = -1;
 static expert_field ei_comments_text = EI_INIT;
 static expert_field ei_arrive_time_out_of_range = EI_INIT;
 static expert_field ei_incomplete = EI_INIT;
+static expert_field ei_len_lt_caplen = EI_INIT;
 
 static int frame_tap = -1;
 
@@ -292,45 +293,39 @@ frame_add_verdict(wtap_block_t block _U_, guint option_id, wtap_opttype_e option
 	fr_foreach_t *fr_user_data = (fr_foreach_t *)user_data;
 
 	if (option_id == OPT_PKT_VERDICT) {
-		GBytes *verdict = option->byteval;
-		const guint8 *verdict_data;
-		gsize len;
+		packet_verdict_opt_t *verdict = &option->packet_verdictval;
 		char *format = fr_user_data->n_changes ? ", %s (%u)" : "%s (%u)";
 
-		if (verdict == NULL)
-			return TRUE;
-
-		verdict_data = (const guint8 *) g_bytes_get_data(verdict, &len);
-
-		if (len == 0)
-			return TRUE;
-
 		proto_item_append_text(fr_user_data->item, format,
-			 get_verdict_type_string(verdict_data[0]), verdict_data[0]);
+				       get_verdict_type_string(verdict->type),
+				       verdict->type);
 
-		len -= 1;
-		switch(verdict_data[0]) {
-			case OPT_VERDICT_TYPE_HW:
-				proto_tree_add_bytes_with_length(fr_user_data->tree, hf_frame_verdict_hardware,
-						fr_user_data->tvb, 0, 0, verdict_data + 1, (gint) len);
-				break;
+		switch(verdict->type) {
 			case OPT_VERDICT_TYPE_TC:
-				if (len == 8) {
-					gint64 val;
-					memcpy(&val, verdict_data + 1, sizeof(val));
-					proto_tree_add_int64(fr_user_data->tree, hf_frame_verdict_tc, fr_user_data->tvb, 0, 0, val);
-				}
+				proto_tree_add_int64(fr_user_data->tree,
+						     hf_frame_verdict_tc,
+						     fr_user_data->tvb, 0, 0,
+						     verdict->data.verdict_linux_ebpf_tc);
 				break;
 			case OPT_VERDICT_TYPE_XDP:
-				if (len == 8) {
-					gint64 val;
-					memcpy(&val, verdict_data + 1, sizeof(val));
-					proto_tree_add_int64(fr_user_data->tree, hf_frame_verdict_xdp, fr_user_data->tvb, 0, 0, val);
-				}
+				proto_tree_add_int64(fr_user_data->tree,
+						     hf_frame_verdict_xdp,
+						     fr_user_data->tvb, 0, 0,
+						     verdict->data.verdict_linux_ebpf_xdp);
+				break;
+			case OPT_VERDICT_TYPE_HW:
+				proto_tree_add_bytes_with_length(fr_user_data->tree,
+								 hf_frame_verdict_hardware,
+								 fr_user_data->tvb, 0, 0,
+								 verdict->data.verdict_bytes->data,
+								 verdict->data.verdict_bytes->len);
 				break;
 			default:
-				proto_tree_add_bytes_with_length(fr_user_data->tree, hf_frame_verdict_unknown,
-						fr_user_data->tvb, 0, 0, verdict_data, (gint) len + 1);
+				proto_tree_add_bytes_with_length(fr_user_data->tree,
+								 hf_frame_verdict_unknown,
+								 fr_user_data->tvb, 0, 0,
+								 verdict->data.verdict_bytes->data,
+								 verdict->data.verdict_bytes->len);
 				break;
 		}
 	}
@@ -357,7 +352,7 @@ dissect_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, void*
 	dissector_handle_t dissector_handle;
 	fr_foreach_t fr_user_data;
 	struct nflx_tcpinfo tcpinfo;
-	gboolean tcpinfo_filled;
+	gboolean tcpinfo_filled = false;
 
 	tree=parent_tree;
 
@@ -520,19 +515,42 @@ dissect_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, void*
 		wtap_block_foreach_option(fr_data->pkt_block, frame_add_comment, (void *)&fr_user_data);
 	}
 
-	/* if FRAME is not referenced from any filters we don't need to worry about
-	   generating any tree items.  */
+	cap_len = tvb_captured_length(tvb);
+	frame_len = tvb_reported_length(tvb);
+
+	/* If FRAME is not referenced from any filters we don't need to
+	   worry about generating any tree items.
+
+	   We do, however, have to worry about generating expert infos,
+	   as those have to show up if, for example, the user requests
+	   the expert info dialog.
+
+	   NOTE: if any expert infos are added in the "frame is referenced"
+	   arm of the conditional, they must also be added to the "frame
+	   is not referenced" arm.  See, for example, issue #18312.
+
+	   XXX - all these tricks to optimize dissection if only some
+	   information is required are fragile.  Something better that
+	   handles this automatically would be useful. */
 	if (!proto_field_is_referenced(tree, proto_frame)) {
 		tree=NULL;
 		if (pinfo->presence_flags & PINFO_HAS_TS) {
 			if (pinfo->abs_ts.nsecs < 0 || pinfo->abs_ts.nsecs >= 1000000000)
-				expert_add_info(pinfo, NULL, &ei_arrive_time_out_of_range);
+				expert_add_info_format(pinfo, NULL, &ei_arrive_time_out_of_range,
+								    "Arrival Time: Fractional second %09ld is invalid,"
+								    " the valid range is 0-1000000000",
+								    (long) pinfo->abs_ts.nsecs);
+		}
+		if (frame_len < cap_len) {
+			/*
+			 * A reported length less than a captured length
+			 * is bogus, as you cannot capture more data
+			 * than there is in a packet.
+			 */
+			expert_add_info(pinfo, NULL, &ei_len_lt_caplen);
 		}
 	} else {
 		/* Put in frame header information. */
-		cap_len = tvb_captured_length(tvb);
-		frame_len = tvb_reported_length(tvb);
-
 		cap_plurality = plurality(cap_len, "", "s");
 		frame_plurality = plurality(frame_len, "", "s");
 
@@ -780,9 +798,17 @@ dissect_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, void*
 		proto_tree_add_uint(fh_tree, hf_frame_number, tvb,
 				    0, 0, pinfo->num);
 
-		proto_tree_add_uint_format(fh_tree, hf_frame_len, tvb,
-					   0, 0, frame_len, "Frame Length: %u byte%s (%u bits)",
-					   frame_len, frame_plurality, frame_len * 8);
+		item = proto_tree_add_uint_format(fh_tree, hf_frame_len, tvb,
+						  0, 0, frame_len, "Frame Length: %u byte%s (%u bits)",
+						  frame_len, frame_plurality, frame_len * 8);
+		if (frame_len < cap_len) {
+			/*
+			 * A reported length less than a captured length
+			 * is bogus, as you cannot capture more data
+			 * than there is in a packet.
+			 */
+			expert_add_info(pinfo, item, &ei_len_lt_caplen);
+		}
 
 		proto_tree_add_uint_format(fh_tree, hf_frame_capture_len, tvb,
 					   0, 0, cap_len, "Capture Length: %u byte%s (%u bits)",
@@ -850,6 +876,15 @@ dissect_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, void*
 		return tvb_captured_length(tvb);
 	}
 
+	if (frame_len < cap_len) {
+		/*
+		 * Fix the reported length; a reported length less than
+		 * a captured length is bogus, as you cannot capture
+		 * more data than there is in a packet.
+		 */
+		tvb_fix_reported_length(tvb);
+	}
+
 	/* Portable Exception Handling to trap Wireshark specific exceptions like BoundsError exceptions */
 	TRY {
 #ifdef _MSC_VER
@@ -1413,7 +1448,8 @@ proto_register_frame(void)
 	static ei_register_info ei[] = {
 		{ &ei_comments_text, { "frame.comment.expert", PI_COMMENTS_GROUP, PI_COMMENT, "Formatted comment", EXPFILL }},
 		{ &ei_arrive_time_out_of_range, { "frame.time_invalid", PI_SEQUENCE, PI_NOTE, "Arrival Time: Fractional second out of range (0-1000000000)", EXPFILL }},
-		{ &ei_incomplete, { "frame.incomplete", PI_UNDECODED, PI_NOTE, "Incomplete dissector", EXPFILL }}
+		{ &ei_incomplete, { "frame.incomplete", PI_UNDECODED, PI_NOTE, "Incomplete dissector", EXPFILL }},
+		{ &ei_len_lt_caplen, { "frame.len_lt_caplen", PI_MALFORMED, PI_ERROR, "Frame length is less than captured length", EXPFILL }}
 	};
 
 	module_t *frame_module;
