@@ -60,7 +60,7 @@ dissect_gift(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_
 	/* set "Info" column text */
 	col_add_fstr(pinfo->cinfo, COL_INFO, "%s: %s",
 			     is_request ? "Request" : "Response",
-			     format_text(wmem_packet_scope(), line, linelen));
+			     format_text(pinfo->pool, line, linelen));
 
 	/* if tree != NULL, build protocol tree */
 	if (tree) {
@@ -81,10 +81,10 @@ dissect_gift(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_
 		if (tokenlen != 0) {
 			if (is_request) {
 				proto_tree_add_string(cmd_tree, hf_gift_request_cmd, tvb, offset,
-						    tokenlen, format_text(wmem_packet_scope(), line, tokenlen));
+						    tokenlen, format_text(pinfo->pool, line, tokenlen));
 			} else {
 				proto_tree_add_string(cmd_tree, hf_gift_response_cmd, tvb, offset,
-						    tokenlen, format_text(wmem_packet_scope(), line, tokenlen));
+						    tokenlen, format_text(pinfo->pool, line, tokenlen));
 			}
 			offset += (gint) (next_token - line);
 			linelen -= (int) (next_token - line);
@@ -94,10 +94,10 @@ dissect_gift(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_
 		if (linelen != 0) {
 			if (is_request) {
 				proto_tree_add_string(cmd_tree, hf_gift_request_arg, tvb, offset,
-						    linelen, format_text(wmem_packet_scope(), line, linelen));
+						    linelen, format_text(pinfo->pool, line, linelen));
 			} else {
 				proto_tree_add_string(cmd_tree, hf_gift_response_arg, tvb, offset,
-						    linelen, format_text(wmem_packet_scope(), line, linelen));
+						    linelen, format_text(pinfo->pool, line, linelen));
 			}
 		}
 	}
