@@ -27,8 +27,10 @@
 #include <epan/packet.h>
 #include <epan/expert.h>
 #include <epan/conversation.h>
+#include <epan/asn1.h>
 
 #include "packet-gsm_a_common.h"
+#include "packet-gsm_map.h"
 #include "packet-e164.h"
 #include "packet-e212.h"
 #include "packet-dns.h"
@@ -494,6 +496,7 @@ static void dissect_ss_info_ie(tvbuff_t *tvb, packet_info *pinfo, guint offset,
 static void dissect_sm_rp_da_ie(tvbuff_t *tvb, packet_info *pinfo, guint offset,
 				guint ie_len, proto_tree *tree)
 {
+	tvbuff_t *addr_tvb;
 	proto_item *ti;
 	guint8 id_type;
 
@@ -515,8 +518,8 @@ static void dissect_sm_rp_da_ie(tvbuff_t *tvb, packet_info *pinfo, guint offset,
 		break;
 	case OSMO_GSUP_SMS_SM_RP_ODA_MSISDN:
 	case OSMO_GSUP_SMS_SM_RP_ODA_SMSC_ADDR:
-		dissect_e164_msisdn(tvb, tree,
-			offset + 2, ie_len - 2, E164_ENC_BCD);
+		addr_tvb = tvb_new_subset_length(tvb, offset + 1, ie_len - 1);
+		dissect_gsm_map_msisdn(addr_tvb, pinfo, tree);
 		break;
 
 	/* Special case for noSM-RP-DA and noSM-RP-OA */
@@ -539,6 +542,7 @@ static void dissect_sm_rp_da_ie(tvbuff_t *tvb, packet_info *pinfo, guint offset,
 static void dissect_sm_rp_oa_ie(tvbuff_t *tvb, packet_info *pinfo, guint offset,
 				guint ie_len, proto_tree *tree)
 {
+	tvbuff_t *addr_tvb;
 	proto_item *ti;
 	guint8 id_type;
 
@@ -556,8 +560,8 @@ static void dissect_sm_rp_oa_ie(tvbuff_t *tvb, packet_info *pinfo, guint offset,
 	switch (id_type) {
 	case OSMO_GSUP_SMS_SM_RP_ODA_MSISDN:
 	case OSMO_GSUP_SMS_SM_RP_ODA_SMSC_ADDR:
-		dissect_e164_msisdn(tvb, tree,
-			offset + 2, ie_len - 2, E164_ENC_BCD);
+		addr_tvb = tvb_new_subset_length(tvb, offset + 1, ie_len - 1);
+		dissect_gsm_map_msisdn(addr_tvb, pinfo, tree);
 		break;
 
 	/* Special case for noSM-RP-DA and noSM-RP-OA */
@@ -641,7 +645,7 @@ static void dissect_name_ie(tvbuff_t *tvb, packet_info *pinfo _U_, guint offset,
 
 	if (show_name_as_text) {
 		guint8 *str;
-		str = tvb_get_stringzpad(wmem_packet_scope(), tvb, offset, ie_len,  ENC_ASCII|ENC_NA);
+		str = tvb_get_stringzpad(pinfo->pool, tvb, offset, ie_len,  ENC_ASCII|ENC_NA);
 		proto_item_append_text(parent_ti, ": %s", (char *)str);
 	}
 
@@ -665,6 +669,7 @@ static void dissect_name_ie(tvbuff_t *tvb, packet_info *pinfo _U_, guint offset,
 
 
 static gint
+// NOLINTNEXTLINE(misc-no-recursion)
 dissect_gsup_tlvs(tvbuff_t *tvb, int base_offs, int length, packet_info *pinfo, proto_tree *tree,
 		  proto_item *gsup_ti, guint8 msg_type)
 {
@@ -675,9 +680,9 @@ dissect_gsup_tlvs(tvbuff_t *tvb, int base_offs, int length, packet_info *pinfo,
 		guint8 len;
 		proto_item *ti;
 		proto_tree *att_tree;
-		const guchar *apn;
+		const gchar *apn;
 		const gchar *str;
-		guint apn_len;
+		gint apn_len;
 		guint32 ui32;
 
 		tag = tvb_get_guint8(tvb, offset);
@@ -697,6 +702,7 @@ dissect_gsup_tlvs(tvbuff_t *tvb, int base_offs, int length, packet_info *pinfo,
 		proto_tree_add_item(att_tree, hf_gsup_iei, tvb, offset-2, 1, ENC_BIG_ENDIAN);
 		proto_tree_add_uint(att_tree, hf_gsup_ie_len, tvb, offset-1, 1, len);
 
+		increment_dissection_depth(pinfo);
 		switch (tag) {
 		/* Nested TLVs */
 		case OSMO_GSUP_AUTH_TUPLE_IE:
@@ -837,6 +843,7 @@ dissect_gsup_tlvs(tvbuff_t *tvb, int base_offs, int length, packet_info *pinfo,
 			proto_tree_add_item(att_tree, hf_gsup_ie_payload, tvb, offset, len, ENC_NA);
 			break;
 		}
+		decrement_dissection_depth(pinfo);
 
 		offset += len;
 	}
@@ -969,11 +976,11 @@ proto_register_gsup(void)
 		  { "gsup.sm_rp_oa.invalid", PI_PROTOCOL, PI_ERROR,
 		    "Malformed SM-RP-OA IE", EXPFILL } },
 		{ &ei_gsup_ie_len_invalid,
-		  { "gsup.ie.len.invalid", PI_PROTOCOL, PI_MALFORMED,
+		  { "gsup.ie.len.invalid", PI_PROTOCOL, PI_ERROR,
 		    "Invalid Information Element Length", EXPFILL } },
 	};
 
-	proto_gsup = proto_register_protocol("Osmocom General Subscriber Update Protocol", "gsup", "gsup");
+	proto_gsup = proto_register_protocol("Osmocom General Subscriber Update Protocol", "GSUP", "gsup");
 	proto_register_field_array(proto_gsup, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
 
@@ -1002,7 +1009,7 @@ proto_reg_handoff_gsup(void)
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 8
