@@ -67,7 +67,7 @@ static const value_string amr_ft_names[] =
     {0, NULL}
 };
 
-static guint8 amr_ft_bytes[AMR_FT_MAX] = {12, 13, 15, 17, 19, 20, 26, 31, 6};
+static guint8 amr_ft_bytes[AMR_FT_MAX] = {12, 13, 15, 17, 19, 20, 26, 31, 5};
 
 #define OSMUX_AMR_HEADER_LEN 4
 
@@ -260,7 +260,7 @@ static void finish_process_pkt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tr
 static gint
 dissect_osmux(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
 {
-    static const gint *ft_ctr_fields[] = {
+    static int * const ft_ctr_fields[] = {
         &hf_osmux_rtp_m,
         &hf_osmux_ft,
         &hf_osmux_ctr,
@@ -268,7 +268,7 @@ dissect_osmux(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U
         &hf_osmux_amr_q,
         NULL
     };
-    static const gint *amr_ft_cmr_fields[] = {
+    static int * const amr_ft_cmr_fields[] = {
         &hf_osmux_amr_ft,
         &hf_osmux_amr_cmr,
         NULL
@@ -289,7 +289,7 @@ dissect_osmux(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U
         guint8 i;
         guint32 size, temp;
 
-        osmuxh = wmem_new0(wmem_packet_scope(), struct osmux_hdr);
+        osmuxh = wmem_new0(pinfo->pool, struct osmux_hdr);
 
         ft_ctr = tvb_get_guint8(tvb, offset);
 
@@ -565,7 +565,7 @@ void proto_reg_handoff_osmux(void)
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 4
