@@ -18,7 +18,7 @@
 #include <epan/expert.h>
 #include <epan/to_str.h>
 #include <epan/conversation.h>
-#include <epan/wmem/wmem.h>
+#include <epan/wmem_scopes.h>
 
 #include "packet-tcp.h"
 
