@@ -47,7 +47,8 @@ enum {
 	WS_NFNL_SUBSYS_CTHELPER          =  9,
 	WS_NFNL_SUBSYS_NFTABLES          = 10,
 	WS_NFNL_SUBSYS_NFT_COMPAT        = 11,
-	WS_NFNL_SUBSYS_COUNT             = 12,
+	WS_NFNL_SUBSYS_HOOK              = 12,
+	WS_NFNL_SUBSYS_COUNT             = 13,
 };
 
 /* nfnetlink ULOG subsystem types from <include/uapi/linux/netfilter/nfnetlink_log.h> */
@@ -72,6 +73,7 @@ enum ws_nf_inet_hooks {
 	WS_NF_INET_FORWARD      = 2,
 	WS_NF_INET_LOCAL_OUT    = 3,
 	WS_NF_INET_POST_ROUTING = 4,
+	WS_NF_INET_NUMHOOKS     = 5,
 };
 
 /* from <include/uapi/linux/netfilter/nf_conntrack_common.h> */
@@ -160,6 +162,7 @@ enum ws_nfqnl_attr_type {
 	WS_NFQA_SECCTX              = 18,
 	WS_NFQA_VLAN                = 19,
 	WS_NFQA_L2HDR               = 20,
+	WS_NFQA_PRIORITY            = 21,
 };
 
 enum ws_nfqnl_msg_config_cmds {
@@ -268,6 +271,8 @@ enum ws_ctattr_type {
 	WS_CTA_LABELS               = 22,
 	WS_CTA_LABELS_MASK          = 23,
 	WS_CTA_SYNPROXY             = 24,
+	WS_CTA_FILTER               = 25,
+	WS_CTA_STATUS_MASK          = 26,
 };
 
 enum ws_ctattr_help {
@@ -331,13 +336,14 @@ enum ws_ipset_cadt_attr {
 	WS_IPSET_ATTR_CADT_LINENO       = 9,
 	WS_IPSET_ATTR_MARK              = 10,
 	WS_IPSET_ATTR_MARKMASK          = 11,
+	WS_IPSET_ATTR_BITMASK           = 12,
 	/* (reserved up to 16) */
 #define WS_IPSET_ATTR_CADT_MAX            16
-	WS_IPSET_ATTR_GC                = 17,
+	WS_IPSET_ATTR_INITVAL           = 17,
 	WS_IPSET_ATTR_HASHSIZE          = 18,
 	WS_IPSET_ATTR_MAXELEM           = 19,
 	WS_IPSET_ATTR_NETMASK           = 20,
-	WS_IPSET_ATTR_PROBES            = 21,
+	WS_IPSET_ATTR_BUCKETSIZE        = 21,
 	WS_IPSET_ATTR_RESIZE            = 22,
 	WS_IPSET_ATTR_SIZE              = 23,
 	WS_IPSET_ATTR_ELEMENTS          = 24,
@@ -583,6 +589,8 @@ static const value_string nfct_attr_vals[] = {
 	{ WS_CTA_LABELS,                "LABELS" },
 	{ WS_CTA_LABELS_MASK,           "LABELS_MASK" },
 	{ WS_CTA_SYNPROXY,              "SYNPROXY" },
+	{ WS_CTA_FILTER,                "FILTER" },
+	{ WS_CTA_STATUS_MASK,           "STATUS_MASK" },
 	{ 0, NULL }
 };
 
@@ -829,8 +837,8 @@ static int
 dissect_netfilter_ct(tvbuff_t *tvb, netlink_netfilter_info_t *info, struct packet_netlink_data *nl_data, proto_tree *tree, int offset)
 {
 	offset = dissect_netlink_netfilter_header(tvb, tree, offset);
-	return dissect_netlink_attributes(tvb, &hfi_nfct_attr, ett_nfct_attr, info, nl_data,
-					  tree, offset, -1, dissect_nfct_attrs);
+	return dissect_netlink_attributes_to_end(tvb, &hfi_nfct_attr, ett_nfct_attr, info, nl_data,
+						 tree, offset, dissect_nfct_attrs);
 }
 
 /* EXP */
@@ -1010,8 +1018,8 @@ dissect_netfilter_exp(tvbuff_t *tvb, netlink_netfilter_info_t *info, struct pack
 	//enum ws_ctnl_exp_msg_types type = (enum ws_ctnl_exp_msg_types) (info->data->type & 0xff);
 
 	offset = dissect_netlink_netfilter_header(tvb, tree, offset);
-	return dissect_netlink_attributes(tvb, &hfi_nfexp_attr, ett_nfexp_attr, info, nl_data,
-					  tree, offset, -1, dissect_nfexp_attrs);
+	return dissect_netlink_attributes_to_end(tvb, &hfi_nfexp_attr, ett_nfexp_attr, info, nl_data,
+						 tree, offset, dissect_nfexp_attrs);
 }
 
 /* QUEUE */
@@ -1162,6 +1170,7 @@ static const value_string nfq_attr_vals[] = {
 	{ WS_NFQA_SECCTX,               "Security context string" },
 	{ WS_NFQA_VLAN,                 "Packet VLAN info" },
 	{ WS_NFQA_L2HDR,                "Full L2 header" },
+	{ WS_NFQA_PRIORITY,             "Priority" },
 	{ 0, NULL }
 };
 
@@ -1181,6 +1190,7 @@ const value_string netfilter_hooks_vals[] = {
 	{ WS_NF_INET_FORWARD,       "Forward" },
 	{ WS_NF_INET_LOCAL_OUT,     "Local out" },
 	{ WS_NF_INET_POST_ROUTING,  "Post-routing" },
+	{ WS_NF_INET_NUMHOOKS,      "Number of hooks" },
 	{ 0, NULL }
 };
 
@@ -1420,6 +1430,7 @@ dissect_nfq_attrs(tvbuff_t *tvb, void *data, struct packet_netlink_data *nl_data
 		case WS_NFQA_SECCTX:
 		case WS_NFQA_VLAN:
 		case WS_NFQA_L2HDR:
+		case WS_NFQA_PRIORITY:
 			/* TODO */
 			break;
 	}
@@ -1442,11 +1453,11 @@ dissect_netfilter_queue(tvbuff_t *tvb, netlink_netfilter_info_t *info, struct pa
 
 	switch (type) {
 		case WS_NFQNL_MSG_CONFIG:
-			return dissect_netlink_attributes(tvb, &hfi_nfq_config_attr, ett_nfq_config_attr, info, nl_data, tree, offset, -1, dissect_nfq_config_attrs);
+			return dissect_netlink_attributes_to_end(tvb, &hfi_nfq_config_attr, ett_nfq_config_attr, info, nl_data, tree, offset, dissect_nfq_config_attrs);
 
 		case WS_NFQNL_MSG_PACKET:
 		case WS_NFQNL_MSG_VERDICT:
-			return dissect_netlink_attributes(tvb, &hfi_nfq_attr, ett_nfq_attr, info, nl_data, tree, offset, -1, dissect_nfq_attrs);
+			return dissect_netlink_attributes_to_end(tvb, &hfi_nfq_attr, ett_nfq_attr, info, nl_data, tree, offset, dissect_nfq_attrs);
 
 		case WS_NFQNL_MSG_VERDICT_BATCH:
 			/* TODO */
@@ -1538,12 +1549,13 @@ static const value_string ipset_cadt_attr_vals[] = {
 	{ WS_IPSET_ATTR_CADT_LINENO,    "CADT_LINENO" },
 	{ WS_IPSET_ATTR_MARK,           "MARK" },
 	{ WS_IPSET_ATTR_MARKMASK,       "MARKMASK" },
+	{ WS_IPSET_ATTR_BITMASK,        "BITMASK" },
 	/* up to 16 is reserved. */
-	{ WS_IPSET_ATTR_GC,             "GC" },
+	{ WS_IPSET_ATTR_INITVAL,        "INITVAL" },
 	{ WS_IPSET_ATTR_HASHSIZE,       "HASHSIZE" },
 	{ WS_IPSET_ATTR_MAXELEM,        "MAXELEM" },
 	{ WS_IPSET_ATTR_NETMASK,        "NETMASK" },
-	{ WS_IPSET_ATTR_PROBES,         "PROBES" },
+	{ WS_IPSET_ATTR_BUCKETSIZE,     "BUCKETSIZE" },
 	{ WS_IPSET_ATTR_RESIZE,         "RESIZE" },
 	{ WS_IPSET_ATTR_SIZE,           "SIZE" },
 	{ WS_IPSET_ATTR_ELEMENTS,       "ELEMENTS" },
@@ -1710,11 +1722,12 @@ dissect_ipset_cadt_attrs(tvbuff_t *tvb, void *data, struct packet_netlink_data *
 		case WS_IPSET_ATTR_CADT_LINENO:
 		case WS_IPSET_ATTR_MARK:
 		case WS_IPSET_ATTR_MARKMASK:
-		case WS_IPSET_ATTR_GC:
+		case WS_IPSET_ATTR_BITMASK:
+		case WS_IPSET_ATTR_INITVAL:
 		case WS_IPSET_ATTR_HASHSIZE:
 		case WS_IPSET_ATTR_MAXELEM:
 		case WS_IPSET_ATTR_NETMASK:
-		case WS_IPSET_ATTR_PROBES:
+		case WS_IPSET_ATTR_BUCKETSIZE:
 		case WS_IPSET_ATTR_RESIZE:
 		case WS_IPSET_ATTR_SIZE:
 		case WS_IPSET_ATTR_ELEMENTS:
@@ -1826,7 +1839,7 @@ static int
 dissect_netfilter_ipset(tvbuff_t *tvb, netlink_netfilter_info_t *info, struct packet_netlink_data *nl_data, proto_tree *tree, int offset)
 {
 	offset = dissect_netlink_netfilter_header(tvb, tree, offset);
-	return dissect_netlink_attributes(tvb, &hfi_ipset_attr, ett_ipset_attr, info, nl_data, tree, offset, -1, dissect_ipset_attrs);
+	return dissect_netlink_attributes_to_end(tvb, &hfi_ipset_attr, ett_ipset_attr, info, nl_data, tree, offset, dissect_ipset_attrs);
 }
 
 
@@ -1843,6 +1856,7 @@ static const value_string netlink_netfilter_subsystem_vals[] = {
 	{ WS_NFNL_SUBSYS_CTHELPER,          "Connection Tracking Helpers" },
 	{ WS_NFNL_SUBSYS_NFTABLES,          "Netfilter tables" },
 	{ WS_NFNL_SUBSYS_NFT_COMPAT,        "x_tables compatibility layer for nf_tables" },
+	{ WS_NFNL_SUBSYS_HOOK,              "Hook" },
 	{ WS_NFNL_SUBSYS_COUNT,             "Count" },
 	{ 0, NULL }
 };
