@@ -16,6 +16,8 @@
 #include <epan/packet.h>
 #include <epan/arptypes.h>
 #include <epan/exceptions.h>
+#include <epan/prefs.h>
+
 #include <wiretap/wtap.h>
 #include <wsutil/ws_roundup.h>
 
@@ -238,6 +240,7 @@ static int * const netlink_header_standard_flags[] = {
 
 
 static int
+// NOLINTNEXTLINE(misc-no-recursion)
 dissect_netlink_attributes_common(tvbuff_t *tvb, header_field_info *hfi_type, int ett_tree, int ett_attrib, void *data, struct packet_netlink_data *nl_data, proto_tree *tree, int offset, int length, netlink_attributes_cb_t cb)
 {
 	int encoding;
@@ -345,6 +348,9 @@ dissect_netlink_attributes_common(tvbuff_t *tvb, header_field_info *hfi_type, in
 			offset += 2;
 			proto_item_append_text(ti, " %u", rta_type);
 
+			// In theory we should use increment_dissection_depth here, but that
+			// requires adding pinfo all over packet-netlink*.[ch] and we're limited
+			// to 262144 bytes (WTAP_MAX_PACKET_SIZE_STANDARD).
 			dissect_netlink_attributes(tvb, hfi_type, ett_attrib, data, nl_data, attr_tree, offset, rta_len - 4, cb);
 		}
 
@@ -360,6 +366,7 @@ dissect_netlink_attributes_common(tvbuff_t *tvb, header_field_info *hfi_type, in
 }
 
 int
+// NOLINTNEXTLINE(misc-no-recursion)
 dissect_netlink_attributes(tvbuff_t *tvb, header_field_info *hfi_type, int ett, void *data, struct packet_netlink_data *nl_data, proto_tree *tree, int offset, int length, netlink_attributes_cb_t cb)
 {
 	return dissect_netlink_attributes_common(tvb, hfi_type, ett, -1, data, nl_data, tree, offset, length, cb);
