@@ -208,7 +208,7 @@ dissect_pana_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree);
 static void
 dissect_pana_flags(proto_tree *parent_tree, tvbuff_t *tvb, int offset, guint16 flags)
 {
-        static const int * flag_fields[] = {
+        static int * const flag_fields[] = {
             &hf_pana_flag_r,
             &hf_pana_flag_s,
             &hf_pana_flag_c,
@@ -229,7 +229,7 @@ dissect_pana_flags(proto_tree *parent_tree, tvbuff_t *tvb, int offset, guint16 f
 static void
 dissect_pana_avp_flags(proto_tree *parent_tree, tvbuff_t *tvb, int offset, guint16 flags)
 {
-        static const int * flag_fields[] = {
+        static int * const flag_fields[] = {
             &hf_pana_avp_flag_v,
             NULL,
         };
@@ -274,6 +274,7 @@ pana_avp_get_type(guint16 avp_code, guint32 vendor_id)
  * Function for AVP dissector.
  */
 static void
+// NOLINTNEXTLINE(misc-no-recursion)
 dissect_avps(tvbuff_t *tvb, packet_info *pinfo, proto_tree *avp_tree)
 {
 
@@ -365,6 +366,7 @@ dissect_avps(tvbuff_t *tvb, packet_info *pinfo, proto_tree *avp_tree)
                                         group_tvb = tvb_new_subset_length_caplen(tvb, offset,
                                                                    MIN(avp_data_length, tvb_reported_length(tvb)-offset),
                                                                    avp_data_length);
+                                        // We recurse here, but we'll run out of packet before we run out of stack.
                                         dissect_avps(group_tvb, pinfo, avp_group_tree);
                                         break;
                                 }
@@ -425,6 +427,7 @@ dissect_avps(tvbuff_t *tvb, packet_info *pinfo, proto_tree *avp_tree)
                                                                                 tvb, offset, avp_data_length,
                                                                                 ett_pana_avp, NULL, "AVP Value (PANA packet)");
                                         encap_tvb = tvb_new_subset_length(tvb, offset, avp_data_length);
+                                        // We recurse here, but we'll run out of packet before we run out of stack.
                                         dissect_pana_pdu(encap_tvb, pinfo, avp_encap_tree);
                                         break;
                                 }
@@ -443,6 +446,7 @@ dissect_avps(tvbuff_t *tvb, packet_info *pinfo, proto_tree *avp_tree)
  * Function for the PANA PDU dissector.
  */
 static void
+// NOLINTNEXTLINE(misc-no-recursion)
 dissect_pana_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
 
@@ -519,7 +523,7 @@ dissect_pana_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
         if(!pana_trans){
                 /* create a "fake" pana_trans structure */
-                pana_trans=wmem_new(wmem_packet_scope(), pana_transaction_t);
+                pana_trans=wmem_new(pinfo->pool, pana_transaction_t);
                 pana_trans->req_frame=0;
                 pana_trans->rep_frame=0;
                 pana_trans->req_time=pinfo->abs_ts;
@@ -857,8 +861,7 @@ proto_register_pana(void)
         };
 
         /* Register the protocol name and description */
-        proto_pana = proto_register_protocol("Protocol for carrying Authentication for Network Access",
-                                             "PANA", "pana");
+        proto_pana = proto_register_protocol("Protocol for carrying Authentication for Network Access", "PANA", "pana");
 
         /* Required function calls to register the header fields and subtrees used */
         proto_register_field_array(proto_pana, hf, array_length(hf));
@@ -883,7 +886,7 @@ proto_reg_handoff_pana(void)
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 8
