@@ -377,6 +377,7 @@ dissect_protobuf_message(tvbuff_t *tvb, guint offset, guint length, packet_info
  * Return consumed bytes
  */
 static guint
+// NOLINTNEXTLINE(misc-no-recursion)
 dissect_packed_repeated_field_values(tvbuff_t *tvb, guint start, guint length, packet_info *pinfo,
     proto_item *ti_field, int wire_type, int field_type, const gchar* prepend_text, const PbwFieldDescriptor* field_desc)
 {
@@ -484,6 +485,7 @@ dissect_packed_repeated_field_values(tvbuff_t *tvb, guint start, guint length, p
 
 /* Dissect field value based on a specific type. */
 static void
+// NOLINTNEXTLINE(misc-no-recursion)
 protobuf_dissect_field_value(proto_tree *value_tree, tvbuff_t *tvb, guint offset, guint length, packet_info *pinfo,
     proto_item *ti_field, int field_type, const guint64 value, const gchar* prepend_text, const PbwFieldDescriptor* field_desc, gboolean is_top_level)
 {
@@ -754,6 +756,7 @@ protobuf_dissect_field_value(proto_tree *value_tree, tvbuff_t *tvb, guint offset
 
 /* add all possible values according to field types. */
 static void
+// NOLINTNEXTLINE(misc-no-recursion)
 protobuf_try_dissect_field_value_on_multi_types(proto_tree *value_tree, tvbuff_t *tvb, guint offset, guint length,
     packet_info *pinfo, proto_item *ti_field, int* field_types, const guint64 value, const gchar* prepend_text)
 {
@@ -770,6 +773,7 @@ protobuf_try_dissect_field_value_on_multi_types(proto_tree *value_tree, tvbuff_t
 }
 
 static guint
+// NOLINTNEXTLINE(misc-no-recursion)
 dissect_one_protobuf_field(tvbuff_t *tvb, guint* offset, guint maxlen, packet_info *pinfo, proto_tree *protobuf_tree,
     const PbwDescriptor* message_desc, gboolean is_top_level, const PbwFieldDescriptor** field_desc_ptr)
 {
@@ -914,6 +918,7 @@ dissect_one_protobuf_field(tvbuff_t *tvb, guint* offset, guint maxlen, packet_in
     /* add value subtree. we add uint value for numeric field or string for length-delimited at least. */
     value_tree = proto_item_add_subtree(ti_value, ett_protobuf_value);
 
+    increment_dissection_depth(pinfo);
     if (field_desc) {
         if (is_packed_repeated) {
             dissect_packed_repeated_field_values(tvb, *offset, value_length, pinfo, ti_field,
@@ -939,6 +944,7 @@ dissect_one_protobuf_field(tvbuff_t *tvb, guint* offset, guint maxlen, packet_in
                 ti_field, field_types, value_uint64, "");
         }
     }
+    decrement_dissection_depth(pinfo);
 
     if (field_desc && !show_details) {
         proto_item_set_hidden(ti_field_number);
@@ -1228,6 +1234,7 @@ add_missing_fields_with_default_values(tvbuff_t* tvb, guint offset, packet_info*
 }
 
 static void
+// NOLINTNEXTLINE(misc-no-recursion)
 dissect_protobuf_message(tvbuff_t *tvb, guint offset, guint length, packet_info *pinfo, proto_tree *protobuf_tree,
     const PbwDescriptor* message_desc, gboolean is_top_level)
 {
@@ -1286,6 +1293,7 @@ dissect_protobuf_message(tvbuff_t *tvb, guint offset, guint length, packet_info
     }
 
     /* each time we dissect one protobuf field. */
+    increment_dissection_depth(pinfo);
     while (offset < max_offset)
     {
         field_desc = NULL;
@@ -1296,6 +1304,7 @@ dissect_protobuf_message(tvbuff_t *tvb, guint offset, guint length, packet_info
             parsed_fields[parsed_fields_count++] = pbw_FieldDescriptor_number(field_desc);
         }
     }
+    decrement_dissection_depth(pinfo);
 
     /* add default values for missing fields */
     if (add_default_value && field_count > 0) {
@@ -1432,7 +1441,8 @@ dissect_protobuf(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data
 }
 
 static gboolean
-load_all_files_in_dir(PbwDescriptorPool* pool, const gchar* dir_path)
+// NOLINTNEXTLINE(misc-no-recursion)
+load_all_files_in_dir(PbwDescriptorPool* pool, const gchar* dir_path, unsigned depth)
 {
     WS_DIR        *dir;             /* scanned directory */
     WS_DIRENT     *file;            /* current file */
@@ -1440,6 +1450,10 @@ load_all_files_in_dir(PbwDescriptorPool* pool, const gchar* dir_path)
     const gchar   *name;            /* current file or dir name (without parent dir path) */
     gchar         *path;            /* sub file or dir path of dir_path */
 
+    if (depth > prefs.gui_max_tree_depth) {
+        return FALSE;
+    }
+
     if (g_file_test(dir_path, G_FILE_TEST_IS_DIR)) {
         if ((dir = ws_dir_open(dir_path, 0, NULL)) != NULL) {
             while ((file = ws_dir_read_name(dir)) != NULL) {
@@ -1455,7 +1469,7 @@ load_all_files_in_dir(PbwDescriptorPool* pool, const gchar* dir_path)
                         return FALSE;
                     }
                 } else {
-                    if (!load_all_files_in_dir(pool, path)) {
+                    if (!load_all_files_in_dir(pool, path, depth + 1)) {
                         g_free(path);
                         ws_dir_close(dir);
                         return FALSE;
@@ -1771,7 +1785,7 @@ protobuf_reinit(int target)
         /* load all .proto files in the marked search paths, we can invoke FindMethodByName etc later. */
         for (i = 0; i < num_proto_paths; ++i) {
             if ((i < 2) || protobuf_search_paths[i - 2].load_all) {
-                if (!load_all_files_in_dir(pbw_pool, source_paths[i])) {
+                if (!load_all_files_in_dir(pbw_pool, source_paths[i], 0)) {
                     buffer_error("Protobuf: Loading .proto files action stopped!\n");
                     loading_completed = FALSE;
                     break; /* stop loading when error occurs */
