@@ -235,7 +235,7 @@ static const char *get_auth_method_name( guint Number){
     return "Bad method number (not 0-0xff)";
 }
 
-static int display_address(tvbuff_t *tvb, int offset, proto_tree *tree) {
+static int display_address(packet_info *pinfo, tvbuff_t *tvb, int offset, proto_tree *tree) {
 
 /* decode and display the v5 address, return offset of next byte */
 
@@ -256,7 +256,7 @@ static int display_address(tvbuff_t *tvb, int offset, proto_tree *tree) {
         gchar* str;
 
         len = tvb_get_guint8(tvb, offset);
-        str = tvb_get_string_enc(wmem_packet_scope(), tvb, offset+1, len, ENC_ASCII);
+        str = tvb_get_string_enc(pinfo->pool, tvb, offset+1, len, ENC_ASCII);
         proto_tree_add_string(tree, hf_socks_remote_name, tvb, offset, len+1, str);
         offset += (len+1);
         }
@@ -344,7 +344,7 @@ socks_udp_dissector(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* d
         proto_tree_add_item(socks_tree, hf_socks_fragment_number, tvb, offset, 1, ENC_BIG_ENDIAN);
         offset += 1;
 
-        offset = display_address( tvb, offset, socks_tree);
+        offset = display_address(pinfo, tvb, offset, socks_tree);
         hash_info->udp_remote_port = tvb_get_ntohs(tvb, offset);
 
         proto_tree_add_uint( socks_tree, hf_socks_dstport, tvb,
@@ -481,6 +481,7 @@ display_socks_v4(tvbuff_t *tvb, int offset, packet_info *pinfo,
 }
 
 static void
+// NOLINTNEXTLINE(misc-no-recursion)
 client_display_socks_v5(tvbuff_t *tvb, int offset, packet_info *pinfo,
     proto_tree *tree, socks_hash_entry_t *hash_info, sock_state_t* state_info) {
 
@@ -532,7 +533,9 @@ client_display_socks_v5(tvbuff_t *tvb, int offset, packet_info *pinfo,
             (tvb_get_guint8(tvb, offset + 2) == 0) &&
             (tvb_reported_length_remaining(tvb, offset + 2 + num_auth_methods) > 0)) {
                 new_state_info.client = clientV5Command;
+                increment_dissection_depth(pinfo);
                 client_display_socks_v5(tvb, offset, pinfo, tree, hash_info, &new_state_info);
+                decrement_dissection_depth(pinfo);
         }
     }
     else if (state_info->client == clientV5Command) {
@@ -548,7 +551,7 @@ client_display_socks_v5(tvbuff_t *tvb, int offset, packet_info *pinfo,
         proto_tree_add_item( tree, hf_socks_reserved, tvb, offset, 1, ENC_BIG_ENDIAN);
         offset += 1;
 
-        offset = display_address(tvb, offset, tree);
+        offset = display_address(pinfo, tvb, offset, tree);
         proto_tree_add_item( tree, hf_client_port, tvb, offset, 2, ENC_BIG_ENDIAN);
     }
     else if ((state_info->client == clientWaitForAuthReply) &&
@@ -571,12 +574,12 @@ client_display_socks_v5(tvbuff_t *tvb, int offset, packet_info *pinfo,
 
             /* process user name */
             len = tvb_get_guint8(tvb, offset);
-            str = tvb_get_string_enc(wmem_packet_scope(), tvb, offset+1, len, ENC_ASCII);
+            str = tvb_get_string_enc(pinfo->pool, tvb, offset+1, len, ENC_ASCII);
             proto_tree_add_string(tree, hf_socks_username, tvb, offset, len+1, str);
             offset += (len+1);
 
             len = tvb_get_guint8(tvb, offset);
-            str = tvb_get_string_enc(wmem_packet_scope(), tvb, offset+1, len, ENC_ASCII);
+            str = tvb_get_string_enc(pinfo->pool, tvb, offset+1, len, ENC_ASCII);
             proto_tree_add_string(tree, hf_socks_password, tvb, offset, len+1, str);
             /* offset += (len+1); */
             break;
@@ -601,7 +604,7 @@ client_display_socks_v5(tvbuff_t *tvb, int offset, packet_info *pinfo,
 }
 
 static void
-server_display_socks_v5(tvbuff_t *tvb, int offset, packet_info *pinfo _U_,
+server_display_socks_v5(tvbuff_t *tvb, int offset, packet_info *pinfo,
     proto_tree *tree, socks_hash_entry_t *hash_info _U_, sock_state_t* state_info) {
 
 /* Display the protocol tree for the version. This routine uses the */
@@ -685,7 +688,7 @@ server_display_socks_v5(tvbuff_t *tvb, int offset, packet_info *pinfo _U_,
         proto_tree_add_item( tree, hf_socks_reserved, tvb, offset, 1, ENC_BIG_ENDIAN);
         offset += 1;
 
-        offset = display_address(tvb, offset, tree);
+        offset = display_address(pinfo, tvb, offset, tree);
         proto_tree_add_item( tree, hf_client_port, tvb, offset, 2, ENC_BIG_ENDIAN);
         break;
 
@@ -701,7 +704,7 @@ server_display_socks_v5(tvbuff_t *tvb, int offset, packet_info *pinfo _U_,
         proto_tree_add_item( tree, hf_socks_reserved, tvb, offset, 1, ENC_BIG_ENDIAN);
         offset += 1;
 
-        offset = display_address(tvb, offset, tree);
+        offset = display_address(pinfo, tvb, offset, tree);
         proto_tree_add_item( tree, hf_server_remote_host_port, tvb, offset, 2, ENC_BIG_ENDIAN);
         break;
 
@@ -760,6 +763,7 @@ state_machine_v4( socks_hash_entry_t *hash_info, tvbuff_t *tvb,
 }
 
 static void
+// NOLINTNEXTLINE(misc-no-recursion)
 client_state_machine_v5( socks_hash_entry_t *hash_info, tvbuff_t *tvb,
     int offset, packet_info *pinfo, gboolean start_of_frame) {
 
@@ -785,7 +789,9 @@ client_state_machine_v5( socks_hash_entry_t *hash_info, tvbuff_t *tvb,
             /* No authentication needed */
             hash_info->clientState = clientV5Command;
             if (tvb_reported_length_remaining(tvb, offset + 2 + num_auth_methods) > 0) {
+                increment_dissection_depth(pinfo);
                 client_state_machine_v5(hash_info, tvb, offset + 2 + num_auth_methods, pinfo, FALSE);
+                decrement_dissection_depth(pinfo);
             }
         } else {
             hash_info->clientState = clientWaitForAuthReply;
@@ -885,7 +891,7 @@ server_state_machine_v5( socks_hash_entry_t *hash_info, tvbuff_t *tvb,
             hash_info->serverState = serverBindReply;
             if ((tvb_get_guint8(tvb, offset + 2) == 0) &&
                 (tvb_reported_length_remaining(tvb, offset) > 5)) {
-                    offset = display_address(tvb, offset, NULL);
+                    offset = display_address(pinfo, tvb, offset, NULL);
                     client_state_machine_v5(hash_info, tvb, offset, pinfo, FALSE);
             }
             break;
@@ -970,7 +976,6 @@ static void call_next_dissector(tvbuff_t *tvb, int offset, packet_info *pinfo,
     guint16 save_can_desegment;
     struct tcp_analysis *tcpd=NULL;
 
-    tcpd=get_tcp_conversation_data(NULL,pinfo);
 
     if (( hash_info->command  == PING_COMMAND) ||
         ( hash_info->command  == TRACERT_COMMAND))
@@ -981,13 +986,15 @@ static void call_next_dissector(tvbuff_t *tvb, int offset, packet_info *pinfo,
 
 /*XXX may want to load dest address here */
 
-        if ( pinfo->destport  == TCP_PORT_SOCKS)
-                ptr = &pinfo->destport;
-        else
-                ptr = &pinfo->srcport;
+        if (pinfo->destport == TCP_PORT_SOCKS) {
+            ptr = &pinfo->destport;
+        } else {
+            ptr = &pinfo->srcport;
+        }
 
-            *ptr = hash_info->port;
+        *ptr = hash_info->port;
 
+        tcpd = get_tcp_conversation_data(NULL, pinfo);
 /* 2003-09-18 JCFoster Fixed problem with socks tunnel in socks tunnel */
 
         state_info->in_socks_dissector_flag = 1; /* avoid recursive overflow */
