@@ -10,19 +10,7 @@
  * Updated by Neil Hunter <neil.hunter@energis-squared.com>
  * WTLS support by Alexandre P. Ferreira (Splice IP)
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "config.h"
@@ -304,6 +292,7 @@ wtp_handle_tpi(proto_tree *tree, tvbuff_t *tvb)
 
 /* Code to actually dissect the packets */
 static void
+// NOLINTNEXTLINE(misc-no-recursion)
 dissect_wtp_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
     char          *szInfo;
@@ -335,7 +324,7 @@ dissect_wtp_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     gint           dataLen;
 
 #define SZINFO_SIZE 256
-    szInfo=(char *)wmem_alloc(wmem_packet_scope(), SZINFO_SIZE);
+    szInfo=(char *)wmem_alloc(pinfo->pool, SZINFO_SIZE);
 
     b0 = tvb_get_guint8 (tvb, offCur + 0);
     /* Discover Concatenated PDUs */
@@ -376,6 +365,7 @@ dissect_wtp_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
             }
             /* Skip the length field for the WTP sub-tvb */
             wtp_tvb = tvb_new_subset_length(tvb, offCur + c_fieldlen, c_pdulen);
+            // We recurse here, but we'll run out of packet before we run out of stack.
             dissect_wtp_common(wtp_tvb, pinfo, wtp_tree);
             offCur += c_fieldlen + c_pdulen;
             i++;
@@ -462,7 +452,7 @@ dissect_wtp_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         fprintf(stderr, "dissect_wtp: cbHeader = %d\n", cbHeader);
 #endif
         /* NOTE - Length will be set when we process the TPI */
-        ti = proto_tree_add_item(tree, proto_wtp, tvb, offCur, 0, ENC_NA);
+        ti = proto_tree_add_item(tree, proto_wtp, tvb, offCur, -1, ENC_NA);
 #ifdef DEBUG
         fprintf(stderr, "dissect_wtp: (7) Returned from proto_tree_add_item\n");
 #endif
@@ -1069,7 +1059,7 @@ proto_reg_handoff_wtp(void)
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 4
