@@ -192,7 +192,7 @@ static void uat_key_record_post_update(void) {
             key_record.frame_num = ZBEE_SEC_PC_KEY; /* means it's a user PC key */
             key_record.label = g_strdup(uat_key_records[i].label);
             memcpy(key_record.key, key, ZBEE_SEC_CONST_KEYSIZE);
-            zbee_pc_keyring = g_slist_prepend(zbee_pc_keyring, g_memdup(&key_record, sizeof(key_record_t)));
+            zbee_pc_keyring = g_slist_prepend(zbee_pc_keyring, g_memdup2(&key_record, sizeof(key_record_t)));
         }
     }
 }
@@ -447,7 +447,7 @@ dissect_zbee_secure(tvbuff_t *tvb, packet_info *pinfo, proto_tree* tree, guint o
     ieee802154_hints_t *ieee_hints;
     ieee802154_map_rec *map_rec = NULL;
 
-    static const int * sec_flags[] = {
+    static int * const sec_flags[] = {
         &hf_zbee_sec_key_id,
         &hf_zbee_sec_nonce,
         NULL
@@ -476,14 +476,14 @@ dissect_zbee_secure(tvbuff_t *tvb, packet_info *pinfo, proto_tree* tree, guint o
      * Eww, I think I just threw up a little...  ZigBee requires this field
      * to be patched before computing the MIC, but we don't have write-access
      * to the tvbuff. So we need to allocate a copy of the whole thing just
-     * so we can fix these 3 bits. Memory allocated by tvb_memdup(wmem_packet_scope(),...)
+     * so we can fix these 3 bits. Memory allocated by tvb_memdup(pinfo->pool,...)
      * is automatically freed before the next packet is processed.
      */
-    enc_buffer = (guint8 *)tvb_memdup(wmem_packet_scope(), tvb, 0, tvb_captured_length(tvb));
+    enc_buffer = (guint8 *)tvb_memdup(pinfo->pool, tvb, 0, tvb_captured_length(tvb));
     /*
      * Override the const qualifiers and patch the security level field, we
      * know it is safe to overide the const qualifiers because we just
-     * allocated this memory via tvb_memdup(wmem_packet_scope(),...).
+     * allocated this memory via tvb_memdup(pinfo->pool,...).
      */
     enc_buffer[offset] = packet.control;
     packet.level    = zbee_get_bit_field(packet.control, ZBEE_SEC_CONTROL_LEVEL);
@@ -518,6 +518,11 @@ dissect_zbee_secure(tvbuff_t *tvb, packet_info *pinfo, proto_tree* tree, guint o
                     /* Map this long address with the ieee short address. */
                     ieee_hints->map_rec = ieee802154_addr_update(&zbee_nwk_map, ieee_hints->src16,
                         ieee_hints->src_pan, packet.src64, pinfo->current_proto, pinfo->num);
+                    if (nwk_hints && !nwk_hints->map_rec) {
+                        /* Map this long address with the nwk layer short address. */
+                        nwk_hints->map_rec = ieee802154_addr_update(&zbee_nwk_map, nwk_hints->src,
+                                ieee_hints->src_pan, packet.src64, pinfo->current_proto, pinfo->num);
+                    }
                 }
                 break;
 
@@ -1224,7 +1229,7 @@ void zbee_sec_add_key_to_keyring(packet_info *pinfo, const guint8 *key)
         if ( !nwk_keyring ) {
             nwk_keyring = (GSList **)g_malloc0(sizeof(GSList*));
             g_hash_table_insert(zbee_table_nwk_keyring,
-                    g_memdup(&nwk_hints->src_pan, sizeof(nwk_hints->src_pan)), nwk_keyring);
+                    g_memdup2(&nwk_hints->src_pan, sizeof(nwk_hints->src_pan)), nwk_keyring);
         }
 
         if ( nwk_keyring ) {
@@ -1235,14 +1240,14 @@ void zbee_sec_add_key_to_keyring(packet_info *pinfo, const guint8 *key)
                 key_record.frame_num = pinfo->num;
                 key_record.label = NULL;
                 memcpy(&key_record.key, key, ZBEE_APS_CMD_KEY_LENGTH);
-                *nwk_keyring = g_slist_prepend(*nwk_keyring, g_memdup(&key_record, sizeof(key_record_t)));
+                *nwk_keyring = g_slist_prepend(*nwk_keyring, g_memdup2(&key_record, sizeof(key_record_t)));
             }
         }
     }
 } /* nwk_add_key_to_keyring */
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 4
