@@ -5,19 +5,7 @@
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #ifndef __PACKET_INFO_H__
@@ -27,6 +15,8 @@
 #include "tvbuff.h"
 #include "address.h"
 
+struct endpoint;
+
 /** @file
  * Dissected packet data and metadata.
  */
@@ -58,10 +48,9 @@ typedef struct _packet_info {
   guint32 num;                      /**< Frame number */
   nstime_t abs_ts;                  /**< Packet absolute time stamp */
   nstime_t rel_ts;                  /**< Relative timestamp (yes, it can be negative) */
-  gint pkt_encap;                   /**< Per-packet encapsulation/data-link type */
   frame_data *fd;
   union wtap_pseudo_header *pseudo_header;
-  struct wtap_pkthdr *phdr;         /**< Record metadata */
+  wtap_rec *rec;                    /**< Record metadata */
   GSList *data_src;                 /**< Frame data sources */
   address dl_src;                   /**< link-layer source address */
   address dl_dst;                   /**< link-layer destination address */
@@ -69,9 +58,7 @@ typedef struct _packet_info {
   address net_dst;                  /**< network-layer destination address */
   address src;                      /**< source address (net if present, DL otherwise )*/
   address dst;                      /**< destination address (net if present, DL otherwise )*/
-  guint32 vlan_id;                  /**< First encountered VLAN Id if pressent otherwise 0 */
-  circuit_type ctype;               /**< type of circuit, for protocols with a VC identifier */
-  guint32 circuit_id;               /**< circuit ID, for protocols with a VC identifier */
+  guint32 vlan_id;                  /**< First encountered VLAN Id if present otherwise 0 */
   const char *noreassembly_reason;  /**< reason why reassembly wasn't done, if any */
   gboolean fragmented;              /**< TRUE if the protocol is only a fragment */
   struct {
@@ -83,6 +70,8 @@ typedef struct _packet_info {
   guint32 destport;                 /**< destination port */
   guint32 match_uint;               /**< matched uint for calling subdissector from table */
   const char *match_string;         /**< matched string for calling subdissector from table */
+  gboolean use_endpoint;            /**< TRUE if endpoint member should be used for conversations */
+  struct endpoint* conv_endpoint;   /**< Data that can be used for conversations */
   guint16 can_desegment;            /**< >0 if this segment could be desegmented.
                                          A dissector that can offer this API (e.g.
                                          TCP) sets can_desegment=2, then
@@ -152,6 +141,9 @@ typedef struct _packet_info {
 
   int link_dir;                 /**< 3GPP messages are sometime different UP link(UL) or Downlink(DL) */
 
+  gint16 src_win_scale;        /**< Rcv.Wind.Shift src applies when sending segments; -1 unknown; -2 disabled */
+  gint16 dst_win_scale;        /**< Rcv.Wind.Shift dst applies when sending segments; -1 unknown; -2 disabled */
+
   GSList* proto_data;          /**< Per packet proto data */
 
   GSList* dependent_frames;     /**< A list of frames which this one depends on */
@@ -161,6 +153,7 @@ typedef struct _packet_info {
   wmem_allocator_t *pool;      /**< Memory pool scoped to the pinfo struct */
   struct epan_session *epan;
   const gchar *heur_list_name;    /**< name of heur list if this packet is being heuristically dissected */
+  int dissection_depth;         /**< The current "depth" or layer number in the current frame */
 } packet_info;
 
 /** @} */
