@@ -19,7 +19,7 @@
 #include <epan/epan.h>
 #include <epan/epan_dissect.h>
 #include <epan/to_str.h>
-#include <epan/to_str-int.h>
+#include <epan/to_str.h>
 #include <epan/expert.h>
 #include <epan/column.h>
 #include <epan/column-info.h>
@@ -1365,7 +1365,8 @@ ek_write_field_value(field_info *fi, write_json_data* pdata)
             tm = gmtime_r(&t->secs, &tm_time);
 #endif
             if (tm != NULL) {
-                strftime(time_string, sizeof(time_string), "%FT%T", tm);
+                /* Some platforms (MinGW-w64) do not support %F or %T. */
+                strftime(time_string, sizeof(time_string), "%Y-%m-%dT%H:%M:%S", tm);
                 json_dumper_value_anyf(pdata->dumper, "\"%s.%09uZ\"", time_string, t->nsecs);
             } else {
                 json_dumper_value_anyf(pdata->dumper, "\"Not representable\"");
@@ -1804,40 +1805,56 @@ print_escaped_xml(FILE *fh, const char *unescaped_string)
 {
     const char *p;
 
-#define ESCAPED_BUFFER_MAX 256
-    static char temp_buffer[ESCAPED_BUFFER_MAX];
+#define ESCAPED_BUFFER_SIZE 256
+#define ESCAPED_BUFFER_LIMIT (ESCAPED_BUFFER_SIZE - (int)sizeof("&quot;"))
+    static char temp_buffer[ESCAPED_BUFFER_SIZE];
     gint        offset = 0;
 
     if (fh == NULL || unescaped_string == NULL) {
         return;
     }
 
-    for (p = unescaped_string; *p != '\0' && (offset<(ESCAPED_BUFFER_MAX-1)); p++) {
+    /* XXX: Why not use xml_escape() from epan/strutil.h ? */
+    for (p = unescaped_string; *p != '\0' && (offset <= ESCAPED_BUFFER_LIMIT); p++) {
         switch (*p) {
         case '&':
-            (void) g_strlcpy(&temp_buffer[offset], "&amp;", ESCAPED_BUFFER_MAX-offset);
+            (void) g_strlcpy(&temp_buffer[offset], "&amp;", ESCAPED_BUFFER_SIZE-offset);
             offset += 5;
             break;
         case '<':
-            (void) g_strlcpy(&temp_buffer[offset], "&lt;", ESCAPED_BUFFER_MAX-offset);
+            (void) g_strlcpy(&temp_buffer[offset], "&lt;", ESCAPED_BUFFER_SIZE-offset);
             offset += 4;
             break;
         case '>':
-            (void) g_strlcpy(&temp_buffer[offset], "&gt;", ESCAPED_BUFFER_MAX-offset);
+            (void) g_strlcpy(&temp_buffer[offset], "&gt;", ESCAPED_BUFFER_SIZE-offset);
             offset += 4;
             break;
         case '"':
-            (void) g_strlcpy(&temp_buffer[offset], "&quot;", ESCAPED_BUFFER_MAX-offset);
+            (void) g_strlcpy(&temp_buffer[offset], "&quot;", ESCAPED_BUFFER_SIZE-offset);
             offset += 6;
             break;
         case '\'':
-            (void) g_strlcpy(&temp_buffer[offset], "&#x27;", ESCAPED_BUFFER_MAX-offset);
+            (void) g_strlcpy(&temp_buffer[offset], "&#x27;", ESCAPED_BUFFER_SIZE-offset);
             offset += 6;
             break;
-        default:
+        case '\t':
+        case '\n':
+        case '\r':
             temp_buffer[offset++] = *p;
+            break;
+        default:
+            /* XML 1.0 doesn't allow ASCII control characters, except
+             * for the three whitespace ones above (which do *not*
+             * include '\v' and '\f', so not the same group as isspace),
+             * even as character references.
+             * There's no official way to escape them, so we'll do this. */
+            if (g_ascii_iscntrl(*p)) {
+                offset += snprintf(&temp_buffer[offset], ESCAPED_BUFFER_SIZE-offset, "\\x%x", (guint8)*p);
+            } else {
+                temp_buffer[offset++] = *p;
+            }
         }
-        if (offset > ESCAPED_BUFFER_MAX-8) {
+        if (offset > ESCAPED_BUFFER_LIMIT) {
             /* Getting close to end of buffer so flush to fh */
             temp_buffer[offset] = '\0';
             fputs(temp_buffer, fh);
