@@ -208,7 +208,14 @@ get_token_len(const guchar *linep, const guchar *lineend,
  *   their universal character names;
  *
  *   shows illegal UTF-8 sequences as a sequence of bytes represented
- *   as C-style hex escapes;
+ *   as C-style hex escapes (XXX: Does not actually do this. Some illegal
+ *   sequences, such as overlong encodings, the sequences reserved for
+ *   UTF-16 surrogate halves (paired or unpaired), and values outside
+ *   Unicode (i.e., the old sequences for code points above U+10FFFF)
+ *   will be decoded in a permissive way. Other illegal sequences,
+ *   such 0xFE and 0xFF and the presence of a continuation byte where
+ *   not expected (or vice versa its absence), are replaced with
+ *   REPLACEMENT CHARACTER.)
  *
  * and return a pointer to it.
  */
@@ -294,7 +301,7 @@ format_text(wmem_allocator_t* allocator, const guchar *string, size_t len)
             gunichar uc;
             guchar first;
 
-            if ((c & 0xe8) == 0xc0) {
+            if ((c & 0xe0) == 0xc0) {
                 /* Starts a 2-byte UTF-8 sequence; 1 byte left */
                 utf8_len = 1;
                 mask = 0x1f;
@@ -315,7 +322,7 @@ format_text(wmem_allocator_t* allocator, const guchar *string, size_t len)
                 utf8_len = 5;
                 mask = 0x01;
             } else {
-                /* 0xfe or 0xff - not valid */
+                /* 0xfe or 0xff or a continuation byte - not valid */
                 utf8_len = -1;
             }
             if (utf8_len > 0) {
@@ -1339,9 +1346,23 @@ xml_escape(const gchar *unescaped)
             case '"':
                 g_string_append(buffer, "&quot;");
                 break;
-            default:
+            case '\t':
+            case '\n':
+            case '\r':
                 g_string_append_c(buffer, c);
                 break;
+            default:
+                /* XML 1.0 doesn't allow ASCII control characters, except
+                 * for the three whitespace ones above (which do *not*
+                 * include '\v' and '\f', so not the same group as isspace),
+                 * even as character references.
+                 * There's no official way to escape them, so we'll do this. */
+                if (g_ascii_iscntrl(c)) {
+                    g_string_append_printf(buffer, "\\x%x", c);
+                } else {
+                    g_string_append_c(buffer, c);
+                }
+                break;
         }
     }
     /* Return the string value contained within the GString
@@ -1682,15 +1703,6 @@ string_replace(const gchar* str, const gchar *old_val, const gchar *new_val)
     return new_str;
 }
 
-gchar*
-format_size_wmem(wmem_allocator_t *allocator, gint64 size, format_size_flags_e flags)
-{
-    gchar *str = format_size(size, flags);
-    gchar *ptr = wmem_strdup(allocator, str);
-    g_free(str);
-    return ptr;
-}
-
 /*
  * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
