@@ -40,11 +40,11 @@ WSLUA_CONSTRUCTOR Dissector_get (lua_State *L) {
 
     if ((d = find_dissector(name))) {
         pushDissector(L, d);
-        WSLUA_RETURN(1); /* The Dissector reference. */
+    } else {
+        lua_pushnil(L);
     }
 
-    WSLUA_ARG_ERROR(Dissector_get,NAME,"No such dissector");
-    return 0;
+    WSLUA_RETURN(1); /* The <<lua_class_Dissector,`Dissector`>> reference if found, otherwise `nil`. */
 }
 
 /* Allow dissector key names to be sorted alphabetically. */
@@ -151,28 +151,26 @@ int Dissector_register(lua_State* L) {
 
 WSLUA_CLASS_DEFINE(DissectorTable,NOP);
 /*
- A table of subdissectors of a particular protocol (e.g. TCP subdissectors like http, smtp,
- sip are added to table "tcp.port").
+    A table of subdissectors of a particular protocol (e.g. TCP subdissectors like http, smtp, sip are added to table "tcp.port").
 
- Useful to add more dissectors to a table so that they appear in the Decode As... dialog.
+    Useful to add more dissectors to a table so that they appear in the “Decode As...” dialog.
  */
 
 static int dissectortable_table_ref = LUA_NOREF;
 
 WSLUA_CONSTRUCTOR DissectorTable_new (lua_State *L) {
-    /* Creates a new DissectorTable for your dissector's use. */
-#define WSLUA_ARG_DissectorTable_new_TABLENAME 1 /* The short name of the table. */
-#define WSLUA_OPTARG_DissectorTable_new_UINAME 2 /* The name of the table in the User Interface
-                                                    (defaults to the name given). */
-#define WSLUA_OPTARG_DissectorTable_new_TYPE 3 /* Either `ftypes.UINT8`, `ftypes.UINT16`,
+    /* Creates a new `DissectorTable` for your dissector's use. */
+#define WSLUA_ARG_DissectorTable_new_TABLENAME 1 /* The short name of the table. Use lower-case alphanumeric, dot, and/or underscores (e.g., "ansi_map.tele_id" or "udp.port"). */
+#define WSLUA_OPTARG_DissectorTable_new_UINAME 2 /* The name of the table in the user interface.
+                                                    Defaults to the name given in `tablename`, but can be any string. */
+#define WSLUA_OPTARG_DissectorTable_new_TYPE 3 /* One of `ftypes.UINT8`, `ftypes.UINT16`,
                                                   `ftypes.UINT24`, `ftypes.UINT32`, or
-                                                  `ftypes.STRING`
-                                                  (defaults to `ftypes.UINT32`). */
-#define WSLUA_OPTARG_DissectorTable_new_BASE 4 /* Either `base.NONE`, `base.DEC`, `base.HEX`,
-                                                  `base.OCT`, `base.DEC_HEX` or `base.HEX_DEC`
-                                                  (defaults to `base.DEC`). */
-#define WSLUA_OPTARG_DissectorTable_new_PROTO 5 /* The protocol that uses this dissector table
-                                                   (a Proto object). */
+                                                  `ftypes.STRING`.
+                                                  Defaults to `ftypes.UINT32`. */
+#define WSLUA_OPTARG_DissectorTable_new_BASE 4 /* One of `base.NONE`, `base.DEC`, `base.HEX`,
+                                                  `base.OCT`, `base.DEC_HEX` or `base.HEX_DEC`.
+                                                  Defaults to `base.DEC`. */
+#define WSLUA_OPTARG_DissectorTable_new_PROTO 5 /* The <<lua_class_Proto,`Proto`>> object that uses this dissector table. */
     const gchar* name = (const gchar*)luaL_checkstring(L,WSLUA_ARG_DissectorTable_new_TABLENAME);
     const gchar* ui_name = (const gchar*)luaL_optstring(L,WSLUA_OPTARG_DissectorTable_new_UINAME,name);
     enum ftenum type = (enum ftenum)luaL_optinteger(L,WSLUA_OPTARG_DissectorTable_new_TYPE,FT_UINT32);
@@ -288,6 +286,35 @@ WSLUA_CONSTRUCTOR DissectorTable_heuristic_list (lua_State *L) {
     WSLUA_RETURN(1); /* The array table of registered heuristic list names */
 }
 
+WSLUA_CONSTRUCTOR DissectorTable_try_heuristics (lua_State *L) {
+    /*
+     Try all the dissectors in a given heuristic dissector table.
+     */
+#define WSLUA_ARG_DissectorTable_try_heuristics_LISTNAME 1 /* The name of the heuristic dissector. */
+#define WSLUA_ARG_DissectorTable_try_heuristics_TVB 2 /* The buffer to dissect. */
+#define WSLUA_ARG_DissectorTable_try_heuristics_PINFO 3 /* The packet info. */
+#define WSLUA_ARG_DissectorTable_try_heuristics_TREE 4 /* The tree on which to add the protocol items. */
+
+    const gchar* name = luaL_checkstring(L,WSLUA_ARG_DissectorTable_try_heuristics_LISTNAME);
+    Tvb tvb = checkTvb(L,WSLUA_ARG_DissectorTable_try_heuristics_TVB);
+    Pinfo pinfo = checkPinfo(L,WSLUA_ARG_DissectorTable_try_heuristics_PINFO);
+    TreeItem tree = checkTreeItem(L,WSLUA_ARG_DissectorTable_try_heuristics_TREE);
+    heur_dissector_list_t list;
+    heur_dtbl_entry_t *entry;
+
+    if (!(name && tvb && pinfo && tree)) return 0;
+
+    list = find_heur_dissector_list(name);
+    if (!list) {
+        luaL_error(L, "Heuristic list '%s' does not exist", name);
+        return 0;
+    }
+
+    lua_pushboolean(L, dissector_try_heuristic(list, tvb->ws_tvb, pinfo->ws_pinfo, tree->tree, &entry, NULL));
+
+    WSLUA_RETURN(1); /* True if the packet was recognized by the sub-dissector (stop dissection here). */
+}
+
 WSLUA_CONSTRUCTOR DissectorTable_get (lua_State *L) {
     /*
      Obtain a reference to an existing dissector table.
@@ -305,21 +332,20 @@ WSLUA_CONSTRUCTOR DissectorTable_get (lua_State *L) {
         dt->expired = FALSE;
 
         pushDissectorTable(L, dt);
-
-        WSLUA_RETURN(1); /* The DissectorTable. */
+    } else {
+        lua_pushnil(L);
     }
 
-    WSLUA_ARG_ERROR(DissectorTable_get,TABLENAME,"no such dissector_table");
-    return 0;
+    WSLUA_RETURN(1); /* The <<lua_class_DissectorTable,`DissectorTable`>> reference if found, otherwise `nil`. */
 }
 
 WSLUA_METHOD DissectorTable_add (lua_State *L) {
     /*
-     Add a `Proto` with a dissector function, or a `Dissector` object, to the dissector table.
+     Add a <<lua_class_Proto,`Proto`>> with a dissector function or a <<lua_class_Dissector,`Dissector`>> object to the dissector table.
      */
 #define WSLUA_ARG_DissectorTable_add_PATTERN 2 /* The pattern to match (either an integer, a
                                                   integer range or a string depending on the table's type). */
-#define WSLUA_ARG_DissectorTable_add_DISSECTOR 3 /* The dissector to add (either a `Proto` or a `Dissector`). */
+#define WSLUA_ARG_DissectorTable_add_DISSECTOR 3 /* The dissector to add (either a <<lua_class_Proto,`Proto`>> or a <<lua_class_Dissector,`Dissector`>>). */
 
     DissectorTable dt = checkDissectorTable(L,1);
     ftenum_t type;
@@ -352,7 +378,7 @@ WSLUA_METHOD DissectorTable_add (lua_State *L) {
         g_free (pattern);
     } else if ( type == FT_UINT32 || type == FT_UINT16 || type ==  FT_UINT8 || type ==  FT_UINT24 ) {
         if (lua_isnumber(L, WSLUA_ARG_DissectorTable_add_PATTERN)) {
-            int port = (int)luaL_checkinteger(L, WSLUA_ARG_DissectorTable_add_PATTERN);
+            guint32 port = wslua_checkguint32(L, WSLUA_ARG_DissectorTable_add_PATTERN);
             dissector_add_uint(dt->name, port, handle);
         } else {
             /* Not a number, try as range */
@@ -376,12 +402,12 @@ WSLUA_METHOD DissectorTable_add (lua_State *L) {
 
 WSLUA_METHOD DissectorTable_set (lua_State *L) {
     /*
-     Remove existing dissectors from a table and add a new or a range of new dissectors.
+     Clear all existing dissectors from a table and add a new dissector or a range of new dissectors.
 
      @since 1.11.3
      */
 #define WSLUA_ARG_DissectorTable_set_PATTERN 2 /* The pattern to match (either an integer, a integer range or a string depending on the table's type). */
-#define WSLUA_ARG_DissectorTable_set_DISSECTOR 3 /* The dissector to add (either a `Proto` or a `Dissector`). */
+#define WSLUA_ARG_DissectorTable_set_DISSECTOR 3 /* The dissector to add (either a <<lua_class_Proto,`Proto`>> or a <<lua_class_Dissector,`Dissector`>>). */
 
     DissectorTable dt = checkDissectorTable(L,1);
     ftenum_t type;
@@ -414,7 +440,7 @@ WSLUA_METHOD DissectorTable_set (lua_State *L) {
         dissector_add_string(dt->name, pattern,handle);
     } else if ( type == FT_UINT32 || type == FT_UINT16 || type ==  FT_UINT8 || type ==  FT_UINT24 ) {
         if (lua_isnumber(L, WSLUA_ARG_DissectorTable_set_PATTERN)) {
-            int port = (int)luaL_checkinteger(L, WSLUA_ARG_DissectorTable_set_PATTERN);
+            guint32 port = wslua_checkguint32(L, WSLUA_ARG_DissectorTable_set_PATTERN);
             dissector_delete_all(dt->name, handle);
             dissector_add_uint(dt->name, port, handle);
         } else {
@@ -440,10 +466,10 @@ WSLUA_METHOD DissectorTable_set (lua_State *L) {
 
 WSLUA_METHOD DissectorTable_remove (lua_State *L) {
     /*
-     Remove a dissector or a range of dissectors from a table
+     Remove a dissector or a range of dissectors from a table.
      */
 #define WSLUA_ARG_DissectorTable_remove_PATTERN 2 /* The pattern to match (either an integer, a integer range or a string depending on the table's type). */
-#define WSLUA_ARG_DissectorTable_remove_DISSECTOR 3 /* The dissector to remove (either a `Proto` or a `Dissector`). */
+#define WSLUA_ARG_DissectorTable_remove_DISSECTOR 3 /* The dissector to remove (either a <<lua_class_Proto,`Proto`>> or a <<lua_class_Dissector,`Dissector`>>). */
     DissectorTable dt = checkDissectorTable(L,1);
     ftenum_t type;
     Dissector handle;
@@ -470,7 +496,7 @@ WSLUA_METHOD DissectorTable_remove (lua_State *L) {
         g_free (pattern);
     } else if ( type == FT_UINT32 || type == FT_UINT16 || type ==  FT_UINT8 || type ==  FT_UINT24 ) {
         if (lua_isnumber(L, WSLUA_ARG_DissectorTable_remove_PATTERN)) {
-          int port = (int)luaL_checkinteger(L, WSLUA_ARG_DissectorTable_remove_PATTERN);
+          guint32 port = wslua_checkguint32(L, WSLUA_ARG_DissectorTable_remove_PATTERN);
           dissector_delete_uint(dt->name, port, handle);
         } else {
             /* Not a number, try as range */
@@ -496,7 +522,7 @@ WSLUA_METHOD DissectorTable_remove_all (lua_State *L) {
 
      @since 1.11.3
      */
-#define WSLUA_ARG_DissectorTable_remove_all_DISSECTOR 2 /* The dissector to remove (either a `Proto` or a `Dissector`). */
+#define WSLUA_ARG_DissectorTable_remove_all_DISSECTOR 2 /* The dissector to remove (either a <<lua_class_Proto,`Proto`>> or a <<lua_class_Dissector,`Dissector`>>). */
     DissectorTable dt = checkDissectorTable(L,1);
     Dissector handle;
 
@@ -521,12 +547,12 @@ WSLUA_METHOD DissectorTable_remove_all (lua_State *L) {
 
 WSLUA_METHOD DissectorTable_try (lua_State *L) {
     /*
-     Try to call a dissector from a table
+     Try to call a dissector from a table.
      */
 #define WSLUA_ARG_DissectorTable_try_PATTERN 2 /* The pattern to be matched (either an integer or a string depending on the table's type). */
-#define WSLUA_ARG_DissectorTable_try_TVB 3 /* The buffer to dissect. */
-#define WSLUA_ARG_DissectorTable_try_PINFO 4 /* The packet info. */
-#define WSLUA_ARG_DissectorTable_try_TREE 5 /* The tree on which to add the protocol items. */
+#define WSLUA_ARG_DissectorTable_try_TVB 3 /* The <<lua_class_Tvb,`Tvb`>> to dissect. */
+#define WSLUA_ARG_DissectorTable_try_PINFO 4 /* The packet's <<lua_class_Pinfo,`Pinfo`>>. */
+#define WSLUA_ARG_DissectorTable_try_TREE 5 /* The <<lua_class_TreeItem,`TreeItem`>> on which to add the protocol items. */
     DissectorTable volatile dt = checkDissectorTable(L,1);
     Tvb tvb = checkTvb(L,WSLUA_ARG_DissectorTable_try_TVB);
     Pinfo pinfo = checkPinfo(L,WSLUA_ARG_DissectorTable_try_PINFO);
@@ -550,7 +576,7 @@ WSLUA_METHOD DissectorTable_try (lua_State *L) {
                 handled = TRUE;
             }
         } else if ( type == FT_UINT32 || type == FT_UINT16 || type ==  FT_UINT8 || type ==  FT_UINT24 ) {
-            int port = (int)luaL_checkinteger(L, WSLUA_ARG_DissectorTable_try_PATTERN);
+            guint32 port = wslua_checkguint32(L, WSLUA_ARG_DissectorTable_try_PATTERN);
 
             len = dissector_try_uint(dt->table,port,tvb->ws_tvb,pinfo->ws_pinfo,ti->tree);
             if (len > 0) {
@@ -593,27 +619,27 @@ WSLUA_METHOD DissectorTable_get_dissector (lua_State *L) {
         const gchar* pattern = luaL_checkstring(L,WSLUA_ARG_DissectorTable_get_dissector_PATTERN);
         handle = dissector_get_string_handle(dt->table,pattern);
     } else if ( type == FT_UINT32 || type == FT_UINT16 || type ==  FT_UINT8 || type ==  FT_UINT24 ) {
-        int port = (int)luaL_checkinteger(L, WSLUA_ARG_DissectorTable_get_dissector_PATTERN);
+        guint32 port = wslua_checkguint32(L, WSLUA_ARG_DissectorTable_get_dissector_PATTERN);
         handle = dissector_get_uint_handle(dt->table,port);
     }
 
     if (handle) {
         pushDissector(L,handle);
-        WSLUA_RETURN(1); /* The dissector handle if found. */
     } else {
         lua_pushnil(L);
-        WSLUA_RETURN(1); /* nil if not found. */
     }
+
+    WSLUA_RETURN(1); /* The <<lua_class_Dissector,`Dissector`>> handle if found, otherwise `nil` */
 }
 
 WSLUA_METHOD DissectorTable_add_for_decode_as (lua_State *L) {
     /*
-     Add the given `Proto` to the "Decode as..." list for this DissectorTable.
-     The passed-in `Proto` object's `dissector()` function is used for dissecting.
+     Add the given <<lua_class_Proto,`Proto`>> to the “Decode as...” list for this DissectorTable.
+     The passed-in <<lua_class_Proto,`Proto`>> object's `dissector()` function is used for dissecting.
 
      @since 1.99.1
      */
-#define WSLUA_ARG_DissectorTable_add_for_decode_as_PROTO 2 /* The `Proto` to add. */
+#define WSLUA_ARG_DissectorTable_add_for_decode_as_PROTO 2 /* The <<lua_class_Proto,`Proto`>> to add. */
     DissectorTable dt = checkDissectorTable(L,1);
     Proto proto = checkProto(L, WSLUA_ARG_DissectorTable_add_for_decode_as_PROTO);
     dissector_handle_t handle = NULL;
@@ -631,7 +657,7 @@ WSLUA_METHOD DissectorTable_add_for_decode_as (lua_State *L) {
 
 /* XXX It would be nice to iterate and print which dissectors it has */
 WSLUA_METAMETHOD DissectorTable__tostring(lua_State* L) {
-    /* Gets some debug information about the DissectorTable. */
+    /* Gets some debug information about the <<lua_class_DissectorTable,`DissectorTable`>>. */
     DissectorTable dt = checkDissectorTable(L,1);
     GString* s;
     ftenum_t type;
@@ -667,7 +693,7 @@ WSLUA_METAMETHOD DissectorTable__tostring(lua_State* L) {
 
     lua_pushstring(L,s->str);
     g_string_free(s,TRUE);
-    WSLUA_RETURN(1); /* A string of debug information about the DissectorTable. */
+    WSLUA_RETURN(1); /* A string of debug information about the <<lua_class_DissectorTable,`DissectorTable`>>. */
 }
 
 /* Gets registered as metamethod automatically by WSLUA_REGISTER_CLASS/META */
@@ -691,6 +717,7 @@ WSLUA_METHODS DissectorTable_methods[] = {
     WSLUA_CLASS_FNREG(DissectorTable,get),
     WSLUA_CLASS_FNREG(DissectorTable,list),
     WSLUA_CLASS_FNREG(DissectorTable,heuristic_list),
+    WSLUA_CLASS_FNREG(DissectorTable,try_heuristics),
     WSLUA_CLASS_FNREG(DissectorTable,add),
     WSLUA_CLASS_FNREG(DissectorTable,set),
     WSLUA_CLASS_FNREG(DissectorTable,remove),
@@ -731,7 +758,7 @@ int wslua_deregister_dissector_tables(lua_State* L) {
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 4
