@@ -109,7 +109,7 @@ WSLUA_CONSTRUCTOR Proto_new(lua_State* L) { /* Creates a new <<lua_class_Proto,`
         return 0;
     }
 
-    proto = g_new(wslua_proto_t, 1);
+    proto = g_new0(wslua_proto_t, 1);
 
     proto->name = hiname;
     proto->loname = loname;
@@ -652,7 +652,7 @@ int wslua_deregister_protocols(lua_State* L) {
         }
         lua_pop(L, 1);
 
-        if (proto->hfa->len) {
+        if (proto->hfa && proto->hfa->len) {
             proto_add_deregistered_data(g_array_free(proto->hfa,FALSE));
         } else {
             g_array_free(proto->hfa,TRUE);
@@ -661,7 +661,7 @@ int wslua_deregister_protocols(lua_State* L) {
         /* No need for deferred deletion of subtree indexes */
         g_array_free(proto->etta,TRUE);
 
-        if (proto->eia->len) {
+        if (proto->eia && proto->eia->len) {
             proto_add_deregistered_data(g_array_free(proto->eia,FALSE));
         } else {
             g_array_free(proto->eia,TRUE);
@@ -718,7 +718,7 @@ int Proto_commit(lua_State* L) {
 
             // XXX this will leak resources.
             if (f->hfid != -2) {
-                return luaL_error(L,"fields can be registered only once");
+                return luaL_error(L,"%s is already registered; fields can be registered only once", f->abbrev);
             }
 
             f->hfid = -1;
@@ -749,7 +749,7 @@ int Proto_commit(lua_State* L) {
             eiri.eiinfo.summary  = e->text;
 
             if (e->ids.ei != EI_INIT_EI || e->ids.hf != -2) {
-                return luaL_error(L,"expert fields can be registered only once");
+                return luaL_error(L,"%s is already registered; expert fields can be registered only once", e->abbrev);
             }
 
             e->ids.hf = -1;
