@@ -5,7 +5,7 @@
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
- * SPDX-License-Identifier: GPL-2.0+
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include <config.h>
@@ -32,24 +32,25 @@ struct tvb_frame {
 };
 
 static gboolean
-frame_read(struct tvb_frame *frame_tvb, struct wtap_pkthdr *phdr, Buffer *buf)
+frame_read(struct tvb_frame *frame_tvb, wtap_rec *rec, Buffer *buf)
 {
 	int    err;
 	gchar *err_info;
+	gboolean ok = TRUE;
 
 	/* XXX, what if phdr->caplen isn't equal to
 	 * frame_tvb->tvb.length + frame_tvb->offset?
 	 */
-	if (!wtap_seek_read(frame_tvb->prov->wth, frame_tvb->file_off, phdr, buf, &err, &err_info)) {
+	if (!wtap_seek_read(frame_tvb->prov->wth, frame_tvb->file_off, rec, buf, &err, &err_info)) {
 		/* XXX - report error! */
 		switch (err) {
 			case WTAP_ERR_BAD_FILE:
 				g_free(err_info);
+				ok = FALSE;
 				break;
 		}
-		return FALSE;
 	}
-	return TRUE;
+	return ok;
 }
 
 static GPtrArray *buffer_cache = NULL;
@@ -57,28 +58,28 @@ static GPtrArray *buffer_cache = NULL;
 static void
 frame_cache(struct tvb_frame *frame_tvb)
 {
-	struct wtap_pkthdr phdr; /* Packet header */
+	wtap_rec rec; /* Record metadata */
 
-	wtap_phdr_init(&phdr);
+	wtap_rec_init(&rec);
 
 	if (frame_tvb->buf == NULL) {
-		if G_UNLIKELY(!buffer_cache) buffer_cache = g_ptr_array_sized_new(1024);
+		if (G_UNLIKELY(!buffer_cache)) buffer_cache = g_ptr_array_sized_new(1024);
 
 		if (buffer_cache->len > 0) {
 			frame_tvb->buf = (struct Buffer *) g_ptr_array_remove_index(buffer_cache, buffer_cache->len - 1);
 		} else {
-			frame_tvb->buf = (struct Buffer *) g_malloc(sizeof(struct Buffer));
+			frame_tvb->buf = g_new(struct Buffer, 1);
 		}
 
 		ws_buffer_init(frame_tvb->buf, frame_tvb->tvb.length + frame_tvb->offset);
 
-		if (!frame_read(frame_tvb, &phdr, frame_tvb->buf))
+		if (!frame_read(frame_tvb, &rec, frame_tvb->buf))
 			{ /* TODO: THROW(???); */ }
 	}
 
 	frame_tvb->tvb.real_data = ws_buffer_start_ptr(frame_tvb->buf) + frame_tvb->offset;
 
-	wtap_phdr_cleanup(&phdr);
+	wtap_rec_cleanup(&rec);
 }
 
 static void
@@ -190,10 +191,11 @@ frame_tvbuff_new(const struct packet_provider_data *prov, const frame_data *fd,
 	 * tvb_new_real_data() now there's no one
 	 */
 
-	tvb->real_data       = buf;
-	tvb->length          = fd->cap_len;
-	tvb->reported_length = fd->pkt_len > G_MAXINT ? G_MAXINT : fd->pkt_len;
-	tvb->initialized     = TRUE;
+	tvb->real_data        = buf;
+	tvb->length           = fd->cap_len;
+	tvb->reported_length  = fd->pkt_len > G_MAXINT ? G_MAXINT : fd->pkt_len;
+	tvb->contained_length = tvb->reported_length;
+	tvb->initialized      = TRUE;
 
 	/*
 	 * This is the top-level real tvbuff for this data source,
@@ -240,10 +242,11 @@ frame_clone(tvbuff_t *tvb, guint abs_offset, guint abs_length)
 	cloned_tvb = tvb_new(&tvb_frame_ops);
 
 	/* data will be read when needed */
-	cloned_tvb->real_data       = NULL;
-	cloned_tvb->length          = abs_length;
-	cloned_tvb->reported_length = abs_length; /* XXX? */
-	cloned_tvb->initialized     = TRUE;
+	cloned_tvb->real_data        = NULL;
+	cloned_tvb->length           = abs_length;
+	cloned_tvb->reported_length  = abs_length; /* XXX? */
+	cloned_tvb->contained_length = cloned_tvb->reported_length;
+	cloned_tvb->initialized      = TRUE;
 
 	/*
 	 * This is the top-level real tvbuff for this data source,
@@ -293,10 +296,11 @@ file_tvbuff_new(const struct packet_provider_data *prov, const frame_data *fd,
 	 * tvb_new_real_data() now there's no one
 	 */
 
-	tvb->real_data       = buf;
-	tvb->length          = fd->cap_len;
-	tvb->reported_length = fd->pkt_len > G_MAXINT ? G_MAXINT : fd->pkt_len;
-	tvb->initialized     = TRUE;
+	tvb->real_data        = buf;
+	tvb->length           = fd->cap_len;
+	tvb->reported_length  = fd->pkt_len > G_MAXINT ? G_MAXINT : fd->pkt_len;
+	tvb->contained_length = tvb->reported_length;
+	tvb->initialized      = TRUE;
 
 	/*
 	 * This is the top-level real tvbuff for this data source,
@@ -327,7 +331,7 @@ file_tvbuff_new_buffer(const struct packet_provider_data *prov,
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 8
