@@ -99,9 +99,20 @@ typedef struct tagModuleDiffInfo {
     guint32    modulID;
 } moduleDiffInfo;
 
+typedef struct tagARUUIDFrame {
+    e_guid_t aruuid;
+    guint32  setupframe;
+    guint32  releaseframe;
+    guint16  outputframe;
+    guint16  inputframe;
+} ARUUIDFrame;
+
+extern wmem_list_t *aruuid_frame_setup_list;
 
 extern void init_pn(int proto);
 extern void init_pn_io_rtc1(int proto);
+extern void init_pn_rsi(int proto);
+extern void pn_rsi_reassemble_init(void);
 
 extern void init_pnio_rtc1_station(stationInfo *station_info);
 
@@ -134,6 +145,14 @@ extern int dissect_pn_undecoded(tvbuff_t *tvb, int offset, packet_info *pinfo,
 extern int dissect_pn_user_data(tvbuff_t *tvb, int offset, packet_info *pinfo _U_,
                     proto_tree *tree, guint32 length, const char *text);
 
+extern int dissect_blocks(tvbuff_t *tvb, int offset,
+                    packet_info *pinfo, proto_tree *tree, guint8 *drep);
+
+#define PDU_TYPE_REQ 0x05
+#define PDU_TYPE_RSP 0x06
+
+extern int dissect_rsi_blocks(tvbuff_t* tvb, int offset, packet_info* pinfo, proto_tree* tree, guint8* drep, guint32 u32FOpnumOffsetOpnum, int type);
+
 #define SUBST_DATA  1
 #define FRAG_DATA   2
 
@@ -148,15 +167,30 @@ extern int dissect_pn_padding(tvbuff_t *tvb, int offset, packet_info *pinfo,
 
 extern int dissect_pn_align4(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree);
 
-extern int dissect_PNIO_C_SDU_RTC1(tvbuff_t *tvb, int offset, packet_info *pinfo,
-                    proto_tree *tree, guint8 *drep _U_);
+extern int dissect_PNIO_status(tvbuff_t *tvb, int offset, packet_info *pinfo,
+                    proto_tree *tree, guint8 *drep);
+
+extern int dissect_PNIO_C_SDU_RTC1(tvbuff_t* tvb, int offset, packet_info* pinfo,
+                    proto_tree* tree, guint8* drep _U_, guint16 frameid);
+
+extern int dissect_PNIO_RSI(tvbuff_t *tvb, int offset, packet_info *pinfo,
+                    proto_tree *tree, guint8 *drep);
+
+extern int dissect_PDRsiInstances_block(tvbuff_t *tvb, int offset,
+                    packet_info *pinfo, proto_tree *tree, proto_item *item _U_, guint8 *drep, guint8 u8BlockVersionHigh, guint8 u8BlockVersionLow);
 
 extern void pn_append_info(packet_info *pinfo, proto_item *dcp_item, const char *text);
 
+extern void pn_init_append_aruuid_frame_setup_list(e_guid_t aruuid, guint32 setup);
+
+extern ARUUIDFrame* pn_find_aruuid_frame_setup(packet_info* pinfo);
+
+extern void pn_find_dcp_station_info(stationInfo* station_info, conversation_t* conversation);
+
 extern gboolean dissect_CSF_SDU_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data);
 
 #define MAX_LINE_LENGTH          1024   /* used for fgets() */
 
 /* Read a string from an "xml" file, dropping xml comment blocks */
 #include <stdio.h>
-extern char *pn_fgets(char *str, int n, FILE *stream);
+extern char *pn_fgets(char *str, int n, FILE *stream, wmem_allocator_t *scope);
